openapi: "3.0.0"

info:
  title: Listing creation API
  version: v1
  contact:
    name: us
    email: daten@autoscout24.de
  description: |-
    API for creating listings that will be displayed on the AutoScout24 platform.

externalDocs:
  url: https://listing-creation.api.autoscout24.com/docs
  description: API documentation

servers:
  - url: https://listing-creation.api.autoscout24.com

security:
  - basicAuth: [ ]

paths:
  /customers:
    get:
      operationId: listCustomers
      summary: List all customers the user can operate on behalf of.
      responses:
        '200':
          description: |-
            The customers were correctly retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Customers'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - customers

  /customers/{customerId}/listings:
    post:
      operationId: createListing
      summary: Creates a listing
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will be saved, but not published in the
            AutoScout24 platform. Also, the listing will only be available when
            the same header is set to true in the retrieve listing request.
        - in: header
          name: x-as24-lca-ng-api-listing-auto-completion-toggle
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future..
        - in: header
          name: x-as24-lca-ng-api-pkw-en-vkv-amendment-enabled
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future.
        - in: header
          name: x-as24-lca-ng-api-disable-setting-applied-seal
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future.
        - in: header
          name: x-request-client-is-listing-form
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future.
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/ErrorCulture'
          required: false
          description: |
            Allow to localize the validation error messages to the language corresponding to the given culture.
            Defaults to en-GB.
      requestBody:
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/ListingPayload'
            example:
              additionalFuelTypes:
                - 2
                - 3
              alloyWheelSize: 18
              availability:
                availabilityType: 1
              belgianCarpassMileageUrl: https://public.car-pass.be/vhr/2a0f0719-1b7a-4e42-84e1-c5c746ab1c39
              bodyColor: 2
              bodyColorName: British Racing Green
              bodyType: 1
              countryVersion: AT
              co2Emissions: 23
              consumption:
                combined: 6.3
              crossReferenceId: DATX_002
              cylinderCapacity: 1998
              cylinderCount: 4
              description: 'This car is **great**. \ It has the following features: \ * Low price
                \ * Great interior
              '
              doorCount: 5
              drivetrain: R
              efficiencyClass: 2
              emptyWeight: 1200
              equipment:
                - 1
                - 2
                - 4
                - 15
              euEmissionStandard: '1'
              externalCustomerId: '1'
              firstRegistrationDate: 2015-01
              fuelCategory: B
              gearCount: 6
              germanEmissionsSticker: 1
              hasFullServiceHistory: false
              hasParticleFilter: true
              highlights:
                - fully equipped
                - financing possible
              hsn: '0583'
              includedServices:
                - 1
                - 2
              condition:
                hadAccident: false
              isMetallic: true
              isNonSmoking: true
              lastCamBeltServiceDate: 2016-01
              lastTechnicalServiceDate: 2016-06
              leasingOffers:
                offers:
                  - referenceOfferId: '10'
                    contractType: KilometerLeasing
                    targetGroup: Both
                    grossListPrice: 139999.95
                    isTradeInPossible: true
                    downPayment: 10000
                    finalInstallment: 9000
                    negotiable: false
                    conditions: Begrenztes Angebot, nur bis 31.02.2020.
                    hasTransferCostsIncluded: true
                    transferCosts: 100
                    hasRegistrationCostsIncluded: false
                    registrationCosts: 99
                    leaseTotalAmount: 77005.6
                    netLoanAmount: 35956.34
                    borrowingRate: 95
                    borrowingRateType: Combined
                    effectiveInterestRate: 80
                    bank: Volkswagen Bank AG, Römerstr. 145, 04109 Leipzig
                    refundForLessDistance: 4.65
                    additionalDistanceCost: 12.65
                    dieselEnvironmentalBonus: false
                    duration: 48
                    includedMileage: 15
                    grossMonthlyRate: 1395.95
                    netMonthlyRate: 1095.95
              licencePlate: M-2411-DC
              make: 13
              marketing:
                mia:
                  requestedTier: T20
                  subtitle: First hand, from an authorized dealer. Discount.
                exclusiveOffer:
                  description: 10% off for the first 10 days.
                  endDate: '2020-05-01'
                listingBoost:
                  requested: true
              model: 1641
              modelVersion: Avant
              nextInspectionDate: 2019-01
              offerReferenceId: A12453
              offerType: U
              power: 110
              ppp:
                appliedTier: T30
              previousOwnerCount: 1
              prices:
                public:
                  price: 16500
                  netPrice: 8250
                  vatRate: 50
                  currency: EUR
                  isNegotiable: false
                  isTaxDeductible: true
                  germanEnvironmentalGrant:
                    priceAlreadyDiscounted: false
                    fixedAmount: 500
                dealer:
                  price: 16500
                  currency: EUR
              primaryFuelType: 1
              seatCount: 5
              transmission: M
              tsn: '936'
              twinner:
                key: 'https://data.twinner.com/displaydata/20211210/102/121021_d3ebf51e-1a07-4d97-b0f2-d830bb8601b3/'
              upholsteryColor: 1
              upholsteryType: AL
              vehicleType: C
              vin: AB023475861123745
              warranty: 12
              hasWarranty: true
              wasCabOrRental: false
              mileage: 75000
              publication:
                status: Inactive
                channels:
                  - id: AS24
      responses:
        '201':
          description: |-
            The listing was created successfully
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '202':
          description: |-
            The listing was accepted successfully and marked as Inactive. Requires to process missing properties enrichment.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings
    get:
      operationId: listListings
      summary: List all listings
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, it will only retrieve test listings.
        - in: query
          name: vinStatus
          schema:
            $ref: '#/components/schemas/VinEnrichmentStatus'
          explode: false
          required: false
          description: |
            Allow to filter the listings by vin enrichment status.
      responses:
        '200':
          description: |-
            200 response
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listings'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings

  /customers/{customerId}/seals:
    get:
      operationId: getSealsForCustomer
      summary: Get all the seals for a specific customer
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the seals belong to
      responses:
        '200':
          description: |-
            200 response
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Seals'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - seals

  /customers/{customerId}/listings/{listingId}:
    get:
      operationId: getListing
      summary: Gets a listing
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
            format: guid
          required: true
          description: The ID of the listing
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/Culture'
          explode: false
          required: false
          description: |
            Allow to adjust the listing URL to the AutoScout24 website corresponding to the given culture.
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
      responses:
        '200':
          description: |-
            200 response
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings
    put:
      operationId: updateListing
      summary: Updates a listing
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
        - in: header
          name: x-as24-lca-ng-api-disable-setting-applied-seal
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future.
        - in: header
          name: x-request-client-is-listing-form
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production as it may get removed anytime in the future.
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/ErrorCulture'
          required: false
          description: |
            Allow to localize the validation error messages to the language corresponding to the given culture.
            Defaults to en-GB.
      requestBody:
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/ListingPayload'
            example:
              additionalFuelTypes:
                - 2
                - 3
              availability:
                availabilityType: 1
              belgianCarpassMileageUrl: https://public.car-pass.be/vhr/2a0f0719-1b7a-4e42-84e1-c5c746ab1c39
              bodyColor: 2
              bodyColorName: British Racing Green
              bodyType: 1
              co2Emissions: 23
              consumption:
                combined: 6.3
              countryVersion: AT
              crossReferenceId: DATX_002
              cylinderCapacity: 1998
              cylinderCount: 4
              description: 'This car is **great**. \ It has the following features: \ * Low price
                \ * Great interior
              '
              doorCount: 5
              drivetrain: R
              efficiencyClass: 2
              emptyWeight: 89999999
              equipment:
                - 1
                - 2
              euEmissionStandard: '1'
              externalCustomerId: '1'
              firstRegistrationDate: 2015-01
              fuelCategory: B
              gearCount: 6
              germanEmissionsSticker: 1
              hasFullServiceHistory: false
              hasParticleFilter: true
              hsn: '0583'
              includedServices:
                - 2
              condition:
                hadAccident: false
              isMetallic: true
              isNonSmoking: true
              lastCamBeltServiceDate: 2016-01
              lastTechnicalServiceDate: 2016-06
              leasingOffers:
                offers:
                  - referenceOfferId: '10'
                    contractType: KilometerLeasing
                    targetGroup: Both
                    grossListPrice: 139999.95
                    isTradeInPossible: true
                    downPayment: 10000
                    finalInstallment: 9000
                    negotiable: false
                    conditions: Begrenztes Angebot, nur bis 31.02.2020.
                    hasTransferCostsIncluded: true
                    transferCosts: 100
                    hasRegistrationCostsIncluded: false
                    registrationCosts: 99
                    leaseTotalAmount: 77005.6
                    netLoanAmount: 35956.34
                    borrowingRate: 95
                    borrowingRateType: Combined
                    effectiveInterestRate: 80
                    bank: Volkswagen Bank AG, Römerstr. 145, 04109 Leipzig
                    refundForLessDistance: 4.65
                    additionalDistanceCost: 12.65
                    dieselEnvironmentalBonus: false
                    duration: 48
                    includedMileage: 15
                    grossMonthlyRate: 1395.95
                    netMonthlyRate: 1095.95
              licencePlate: M-2411-DC
              make: 13
              mileage: 75000
              model: 1641
              nextInspectionDate: 2019-01
              offerReferenceId: A12453
              offerType: U
              power: 110
              previousOwnerCount: 1
              prices:
                public:
                  price: 16500
                  netPrice: 8250
                  vatRate: 50
                  currency: EUR
                  isNegotiable: false
                  isTaxDeductible: true
                  germanEnvironmentalGrant:
                    priceAlreadyDiscounted: false
                    fixedAmount: 500
                dealer:
                  price: 16500
                  currency: EUR
              primaryFuelType: 1
              seatCount: 5
              transmission: M
              tsn: '936'
              twinner:
                key: 'https://data.twinner.com/displaydata/20211210/102/121021_d3ebf51e-1a07-4d97-b0f2-d830bb8601b3/'
              upholsteryType: AL
              vehicleType: C
              vin: AB023475861123745
              warranty: 12
              hasWarranty: true
              youtubeVideoUrl: https://www.youtube.com/watch?v=wnKJnWRa_Ks
              images:
                - id: 1797aae6-c962-4522-81cb-a9c3f9761129
                - id: c3a1fae4-4177-4f4a-af63-c7bdaa95f8ed
              publication:
                status: Inactive
                channels:
                  - id: AS24
      responses:
        '200':
          description: |-
            200 response
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '202':
          description: |-
            The listing was accepted successfully and marked as Inactive. Requires to process missing properties enrichment.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings
    patch:
      operationId: partiallyUpdateListing
      summary: Partially updates a listing
      description: >
        This API supports updating listing specific field values without the need to send the whole payload.


        **Note:** Below are the fields not supported by the `patch` API
          * drivingMode (existing value gets removed, patched value is ignored)
          * europalletStorageSpaces (existing value gets removed, patched value is ignored)
          * financingOffer (existing value gets removed, patched value is ignored)
          * firstModelsProductionDate (existing value gets removed, patched value is ignored)
          * highlights (existing value gets removed, patched value is ignored)
          * leasingOffers (existing value gets removed, patched value is ignored)

      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
        - in: header
          name: x-as24-lca-ng-api-pkw-en-vkv-amendment-enabled
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production and will remove anytime in future.
        - in: header
          name: x-as24-lca-ng-api-disable-setting-applied-seal
          schema:
            type: string
            format: boolean
          required: false
          description: |
            This header is optional and completely based on internal testing purposes.
            Never rely on this header in production and will remove anytime in future.
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/ErrorCulture'
          required: false
          description: |
            Allow to localize the validation error messages to the language corresponding to the given culture.
            Defaults to en-GB.
      requestBody:
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/PartialListingPayload'
            example:
              additionalFuelTypes:
                - 2
                - 3
              availability:
                availabilityType: 1
              belgianCarpassMileageUrl: https://public.car-pass.be/vhr/2a0f0719-1b7a-4e42-84e1-c5c746ab1c39
              bodyColor: 2
              bodyColorName: British Racing Green
              bodyType: 1
              co2Emissions: 23
              consumption:
                combined: 6.3
              countryVersion: AT
              crossReferenceId: DATX_002
              cylinderCapacity: 1998
              cylinderCount: 4
              description: 'This car is **great**. \ It has the following features: \ * Low price
                            \ * Great interior
                          '
              doorCount: 5
              drivetrain: R
              efficiencyClass: 2
              emptyWeight: 89999999
              euEmissionStandard: '1'
              externalCustomerId: '1'
              firstRegistrationDate: 2015-01
              fuelCategory: B
              gearCount: 6
              germanEmissionsSticker: 1
              hasFullServiceHistory: false
              hasParticleFilter: true
              hsn: '0583'
              includedServices:
                - 2
              condition:
                hadAccident: false
              isMetallic: true
              isNonSmoking: true
              lastCamBeltServiceDate: 2016-01
              lastTechnicalServiceDate: 2016-06
              leasingOffers:
                offers:
                  - referenceOfferId: '10'
                    contractType: KilometerLeasing
                    targetGroup: Both
                    grossListPrice: 139999.95
                    isTradeInPossible: true
                    downPayment: 10000
                    finalInstallment: 9000
                    negotiable: false
                    conditions: Begrenztes Angebot, nur bis 31.02.2020.
                    hasTransferCostsIncluded: true
                    transferCosts: 100
                    hasRegistrationCostsIncluded: false
                    registrationCosts: 99
                    leaseTotalAmount: 77005.6
                    netLoanAmount: 35956.34
                    borrowingRate: 95
                    borrowingRateType: Combined
                    effectiveInterestRate: 80
                    bank: Volkswagen Bank AG, Römerstr. 145, 04109 Leipzig
                    refundForLessDistance: 4.65
                    additionalDistanceCost: 12.65
                    dieselEnvironmentalBonus: false
                    duration: 48
                    includedMileage: 15
                    grossMonthlyRate: 1395.95
                    netMonthlyRate: 1095.95
              licencePlate: M-2411-DC
              make: 13
              mileage: 75000
              model: 1641
              nextInspectionDate: 2019-01
              offerReferenceId: A12453
              offerType: U
              power: 110
              previousOwnerCount: 1
              prices:
                public:
                  price: 16500
                  netPrice: 8250
                  vatRate: 50
                  currency: EUR
                  isNegotiable: false
                  isTaxDeductible: true
                  germanEnvironmentalGrant:
                    priceAlreadyDiscounted: false
                    fixedAmount: 500
                dealer:
                  price: 16500
                  currency: EUR
              primaryFuelType: 1
              seatCount: 5
              transmission: M
              tsn: '936'
              twinner:
                key: 'https://data.twinner.com/displaydata/20211210/102/121021_d3ebf51e-1a07-4d97-b0f2-d830bb8601b3/'
              upholsteryType: AL
              vehicleType: C
              vin: AB023475861123745
              warranty: 12
              hasWarranty: true
              youtubeVideoUrl: https://www.youtube.com/watch?v=wnKJnWRa_Ks
              publication:
                status: Inactive
                channels:
                  - id: AS24
              marketing:
                mia:
                  subtitle: "new subtitle"
                  requestedTier: "T30"
                listingBoost:
                  requested: true
              sealsOverwriteProtection: true
      responses:
        '200':
          description: |-
            200 response
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '202':
          description: |-
            The listing was accepted successfully and marked as Inactive. Requires to process missing properties enrichment.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Listing'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings
    delete:
      operationId: deleteListing
      summary: Deletes a listing
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
      responses:
        '204':
          description: |-
            Listing successfully deleted
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - listings

  /customers/{customerId}/images:
    post:
      operationId: uploadImage
      summary: Uploads an image
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
      requestBody:
        content:
          image/png:
            schema:
              type: string
              format: binary
          image/jpeg:
            schema:
              type: string
              format: binary

      responses:
        '201':
          description: |-
            The image was successfully uploaded
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ImageReference'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - images

  /customers/{customerId}/listings/{listingId}/360-images/three-sixty-vr:
    post:
      operationId: uploadThreeSixtyVrImage
      summary: Uploads a 360 image of type ThreeSixtyVR
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing which the 360 image will be attached to
        - in: query
          name: format
          schema:
            type: string
            enum:
              - Equirectangular
          required: true
          description: The format of the VR image
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
      requestBody:
        content:
          application/octet-stream:
            schema:
              type: string
              format: binary
      responses:
        '200':
          description: |-
            The image was successfully uploaded and associated with the provided listing. The listing had already
            an image, which has been deleted.
          headers:
            Location:
              schema:
                type: string
                format: uri
              description: URI where the created 360 image can be retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ThreeSixtyVr'
        '201':
          description: |-
            The image was successfully uploaded and associated with the provided listing. The listing did not have
            an image before.
          headers:
            Location:
              schema:
                type: string
                format: uri
              description: URI where the created 360 image can be retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ThreeSixtyVr'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - 360images
    get:
      operationId: listThreeSixtyVrImages
      summary: lists 360 images of type ThreeSixtyVR
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listing belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing whos 360 images will be retrieved
      responses:
        '200':
          description: |-
            The images were successfully retrieved.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ThreeSixtyVrs'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - 360images

  /customers/{customerId}/listings/{listingId}/360-images/three-sixty-vr/{imageId}:
    delete:
      operationId: deleteThreeSixtyVrImage
      summary: Deletes a 360VR image.
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing
        - in: path
          name: imageId
          schema:
            type: string
          required: true
          description: The ID of the 360VR image to be deleted
      responses:
        '404':
          $ref: '#/components/responses/ResourceNotFound'
      tags:
        - 360images

  /customers/{customerId}/listings/{listingId}/360-images/three-sixty-images-collection:
    post:
      operationId: uploadThreeSixtyImagesCollectionImage
      summary: Uploads a 360 image of type ThreeSixtyImagesCollection
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing which the 360 image will be attached to
        - in: header
          name: X-Testmode
          schema:
            type: string
            format: boolean
          required: false
          description: |
            When set to true, the listing will not found unless it was created as a test listing.
      requestBody:
        content:
          application/json:
            schema:
              $ref: '#/components/schemas/ThreeSixtyImagesCollectionPayload'
      responses:
        '200':
          description: |-
            The image was successfully uploaded and associated with the provided listing.
          headers:
            Location:
              schema:
                type: string
                format: uri
              description: URI where the created 360 image can be retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ThreeSixtyImagesCollection'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - 360images
    get:
      operationId: listThreeSixtyImagesCollectionImages
      summary: lists 360 images of type ThreeSixtyImagesCollection
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listing belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing whos 360 images will be retrieved
      responses:
        '200':
          description: |-
            The images were successfully retrieved.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ThreeSixtyImagesCollections'
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - 360images

  /customers/{customerId}/listings/{listingId}/360-images/three-sixty-images-collection/{imageId}:
    delete:
      operationId: deleteThreeSixtyImagesCollectionImage
      summary: Deletes a 360 Images Colleciton image.
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer whom the listings belong to
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The ID of the listing
        - in: path
          name: imageId
          schema:
            type: string
          required: true
          description: The ID of the image to delete
      responses:
        '204':
          description: |-
            Image successfully deleted
        '400':
          $ref: '#/components/responses/BadRequest'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          $ref: '#/components/responses/ResourceNotFound'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - 360images

  /statistics/{customerId}/listings:
    get:
      operationId: getListingStatisticsBatched
      summary: Gets the statistics for all listings of a customer
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer
          example: 123
        - in: query
          name: startToken
          required: false
          example: "eyJ0eXAiOi"
          schema:
            type: string
          description: |
            Currently ignored!
            A opaque start token to retrieve the next batch of statistics.
            If not set, the first batch is returned.
            The startToken can only be obtained from a previous response and may not be set manually.
        - in: query
          name: maxItems
          required: false
          example: 100
          schema:
            type: integer
            minimum: 1
          description: |
            Currently ignored!
            A hint for the maximum number of statistics to return.
            If not set, the maximum number of statistics is returned.
            This parameter is taken as a hint and the server may return more or less results.
      responses:
        '200':
          description: |-
            The statistics were successfully retrieved.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ListingsStatisticsWrapperPaged'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          description: If the customer does not exist, is not active or no statistics are available for the given customer.
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - statistics

  /statistics/{customerId}/listings/{listingId}:
    get:
      operationId: getListingStatisticsSingle
      summary: Gets the statistics for a specific listing of a customer
      parameters:
        - in: path
          name: customerId
          schema:
            type: string
          required: true
          description: The ID of the customer
          example: '123456'
        - in: path
          name: listingId
          schema:
            type: string
          required: true
          description: The GUID ID of the listing
          example: '123e4567-e89b-12d3-a456-426614174000'
      responses:
        '200':
          description: |-
            The statistics were successfully retrieved.
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/ListingsStatisticsWrapper'
        '401':
          $ref: '#/components/responses/AuthenticationFailed'
        '403':
          $ref: '#/components/responses/ResourceNotAuthorized'
        '404':
          description: If the customer does not exist, is not active or no statistics are available for the given customer.
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - statistics

  /seals:
    get:
      operationId: getSeals
      summary: Get the list of all seals
      responses:
        '200':
          description: The seals were correctly retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Seals'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - seals

  /makes:
    get:
      operationId: getMakes
      summary: Gets the list of all makes, and their respective models
      parameters:
        - in: query
          name: makeId
          schema:
            type: array
            items:
              type: integer
          explode: true
          required: false
          description: |
            Allows to filter the response to only contain the makes with the specified identifier.
            Can be multi-valuated if the parameter is included multiple times.
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/Culture'
          explode: false
          required: false
          description: |
            Allow to localize the references names to the language corresponding to the given culture.
      responses:
        '200':
          description: |-
            The makes were correctly retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/Makes'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - makes

  /references:
    get:
      operationId: getReferences
      summary: Gets the list of all references that allow to describe the attributes of a vehicle
      parameters:
        - in: query
          name: referenceType
          schema:
            $ref: '#/components/schemas/ReferenceType'
          explode: true
          required: false
          description: |
            Allows to filter the response to only contain the references of the specified type.
            Can be multi-valuated if the parameter is included multiple times.
        - in: query
          name: culture
          schema:
            $ref: '#/components/schemas/Culture'
          explode: false
          required: false
          description: |
            Allow to localize the references names to the language corresponding to the given culture.
      responses:
        '200':
          description: |-
            The references were correctly retrieved
          content:
            application/json:
              schema:
                $ref: '#/components/schemas/References'
        '429':
          $ref: '#/components/responses/RateLimitExceeded'
        '500':
          $ref: '#/components/responses/ServerError'
        '503':
          $ref: '#/components/responses/ServiceUnavailable'
      tags:
        - references

components:
  securitySchemes:
    basicAuth:
      type: http
      scheme: basic

  responses:
    BadRequest:
      description: |-
        The provided payload (JSON body and/or query parameters) can't be validated
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/Errors'
    AuthenticationFailed:
      description: |
        The supplied user credentials are invalid
    ResourceNotAuthorized:
      description: |
        The requested resource cannot be operated by the supplied user
    ResourceNotFound:
      description: |-
        The requested resource does not exist
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/Errors'
    RateLimitExceeded:
      description: |-
        The rate limit was exceeded. Try again later.
    ServerError:
      description: |
        There was an unexpected error on AutoScout24 side
    ServiceUnavailable:
      description: |
        The service is not available at the moment, likely due to a maintenance being performed
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/Errors'
    UnprocessableEntity:
      description: |
        The service understands the content type of the request entity, and the syntax of the request entity is correct, but it was unable to process the contained instructions.
      content:
        application/json:
          schema:
            $ref: '#/components/schemas/Errors'

  schemas:
    AvailabilityShared:
      type: object
      description: Shared attributes for an availability object.
      properties:
        availabilityType:
          type: integer
          description: |
            The availability of the vehicle. For example, "1" (available immediately)

            > Allowed values can be retrieved via the references API (reference type AvailabilityType)

          example: 1
        deliveryDays:
          type: integer
          enum: [ 1, 2, 3, 4, 5, 6, 7, 14, 21, 28, 42, 60, 90, 120, 150, 180, 270, 360 ]
          description: |
            The number of days it will take to deliver the vehicle

            > Either <code>deliveryDate</code> or <code>deliveryDays</code> must be present if the vehicle is not available immediately (availabilityType <code>2</code> or <code>3</code>)

          example: 7
        deliveryDate:
          type: string
          format: date
          description: |
            The earliest date that the vehicle can be delivered

            > Either <code>deliveryDate</code> or <code>deliveryDays</code> must be present if the vehicle is not available immediately (availabilityType <code>2</code> or <code>3</code>)

          example: 2018-12-01

    Autoproff:
      type: object
      description: Stores autoproff related attributes
      properties:
        mode:
          type: string
          enum: [ "write", "read", "ap_deleted" ]
          description: |
            Autoproff mode of the listing. Attribute can not be set.
          example: "write"

    Availability:
      required: [ availabilityType ]
      allOf:
        - $ref: '#/components/schemas/AvailabilityShared'

    BatteryCommon:
      type: object
      description: Provides information about the vehicle's battery
      properties:
        ownershipType:
          type: string
          example: 2
          description: |
            Ownership type of the battery.
            > Allowed values can be retrieved via the references API (reference type BatteryOwnershipType).
        chargingTime10to80Minutes:
          type: integer
          example: 800
          maximum: 25200
          minimum: 1
          description: |
            The time it takes in minutes to charge this car from 10% to 80% via the fastest way of charging.
        capacity:
          type: integer
          maximum: 999999
          minimum: 0
          description: |
            The capacity of the battery, in kWh.
          example: 5

    BatteryPayload:
      allOf:
        - $ref: '#/components/schemas/BatteryCommon'

    Battery:
      allOf:
        - $ref: '#/components/schemas/BatteryCommon'
        - type: object
          properties:
            capacityUnit:
              type: string
              description: Unit used for capacity field.
              example: "kWh"
    Channel:
      type: object
      description: a reference to a publication channel.
      required:
        - id
      properties:
        id:
          description: The identifier of the channel
          allOf:
            - $ref: '#/components/schemas/ChannelId'
        url:
          type: string
          format: url
          description: The URL where the listing is visible for the given channel
          example: "https://www.autoscout24.de/angebote/bmw-118-cf04da2d-9c57-4758-8735-5257e4eb1cae"

    ChannelId:
      description: |
        The id of a publication channel.
        <code>AS24Dealer</code> means that the vehicle is visible on AutoScout24’s dealer specific platform.
        <code>AS24</code> means that the vehicle is visible on AutoScout24's general platform. Bear in mind this is a superset of 'AS24Dealer'.
        <code>mobile_de</code> means that the vehicle is visible on <code>mobile_de</code> platform. This is not available for all customers yet, contact customer care to learn more.
        <code>autoproff</code> indicates exporting this vehicle to the autoproff account of the dealer. No effect if customer is not an autoproff customer or has not enabled selective exports via customer care.
        <code>autoproff_marketplace_internal</code> indicates exporting this vehicle to the autoproff internal marketplace of the dealer. No effect if customer is not an autoproff customer or has no internal marketplaces.
        At least one publication channel must exist with the value of <code>AS24</code> or <code>AS24Dealer</code>
      type: string
      enum: [ "AS24", "AS24Dealer", "mobile_de", "autoproff", "autoproff_marketplace_internal", "autoproff_marketplace_public" ]
      example: "AS24"

    ChannelReference:
      type: object
      description: a reference to a publication channel.
      required:
        - id
      properties:
        id:
          description: The identifier of the channel
          allOf:
            - $ref: '#/components/schemas/ChannelId'

    Condition:
      type: object
      description: Describes the current condition of the vehicle.
      properties:
        hadAccident:
          type: boolean
          description: Should be set to true if the vehicle has had an accident in the past, irrespective of whether the vehicle has been repaired, or is currently roadworthy.
          example: true
        isCurrentlyDamaged:
          type: boolean
          description: |
            Should be set to true if the vehicle is currently damaged.

            > This attribute is only available for the German market. Its value won't be considered valid and won't be displayed in the AutoScout24 websites from other countries.
          example: true
        isRoadworthy:
          type: boolean
          description: |
            Should be set to true if the vehicle is fit for use on the road.

            > This attribute is only available for the German market. Its value won't be considered valid and won't be displayed in the AutoScout24 websites from other countries.
          example: true
        description:
          type: string
          description: |
            Detailed description of the condition.
          example: |
            This car is **great**. \ It has no accidents: \ * not damaged \ * not painted
        hasRepairedDamages:
          type: boolean
          description: |
            Whether it has damages that are repaired.
          example: true

    Consumption:
      type: object
      description: Provides information about the different fuel and electric consumption the vehicle has.
      properties:
        combined:
          type: number
          minimum: 0.1
          maximum: 99.9
          description: |
            Vehicle’s combined fuel consumption. l/100 km for petrol and diesel vehicles, kg/100km for compressed natural gas and hydrogen vehicles.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), the primary fuel type is not <code>12</code> (Electricity) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden for German dealers when the vehicle type is <code>C</code> (Car) or <code>X</code> (Light Commercial Vehicle) and primary fuel type <code>12</code> (Electricity).

            > However, when both fields <code>primaryFuelType</code> and <code>additionalFuelTypes</code> are set, then both <code>combined</code> and <code>electricCombined</code> are allowed.
          example: 6.3
        electricCombined:
          type: number
          minimum: 0.1
          maximum: 99.9
          description: |
            Electric vehicle’s combined power consumption in kWh/100 km.

            > *Deprecated, use <code>wltp.consumptionElectricCombined</code> or <code>wltp.consumptionElectricCombinedWeighted</code> instead*

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), the primary fuel type is <code>12</code> (Electricity) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden for German dealers when vehicle type <code>C</code> (Car) or <code>X</code> (Light Commercial Vehicle) and primary fuel type different than <code>12</code> (Electricity).

            > However, when both fields <code>primaryFuelType</code> and <code>additionalFuelTypes</code> are set, then both <code>combined</code> and <code>electricCombined</code> are allowed.
          example: 6.6

    Culture:
      description: |
        A combination of country and language in which AutoScout24 offers their service, encoded as a locale.
        The AutoScout24.com domain is offered in English and is represented by the culture <code>en-GB</code>
      type: string
      enum: [ "de-DE", "de-AT", "nl-BE", "fr-BE", "fr-FR", "it-IT", "es-ES", "fr-LU", "en-GB", "nl-NL" ]
      example: de-DE

    ErrorCulture:
      type: string
      enum: [ "de-DE", "de-AT", "it-IT", "en-GB" ]
      example: de-DE
      description: Supported cultures for translating validation error messages.

    CursorPagination:
      type: object
      properties:
        cursorPagination:
          type: object
          example: |
            {
              "startToken": "eyJ0eXAiOi",
              "maxItems": 10000,
              "nextPage": "https://listing-creation.api.autoscout24.com/statistics/123/listings?start_token=eyJ0eXAiOi&max_items=10000"
            }
          required:
            - startToken
            - maxItems
          description: |
            The cursor pagination object. This object is used to paginate through the listings statistics.
          properties:
            startToken:
              type: string
              description: |
                The opaque token used to start the current page.
              example: "eyJ0eXAiOi"
            maxItems:
              type: integer
              description: The applied limit for the number of items in the response.
              example: 10000
            nextPage:
              type: string
              description: |
                The optional URL to retrieve the next page of the cursor pagination.
                If not set, you reached the end of the pagination.
                All previously set parameters will be kept as is.
              example: "https://listing-creation.api.autoscout24.com/statistics/123/listings?start_token=eyJ0eXAiOi&max_items=10000"

    Customer:
      required:
        - id
        - sellId
        - canSetMiaRequestedTier
        - canUseSellOnline
      properties:
        id:
          description: The unique identifier of this customer used throughout the API
          type: string
          example: "2142082683"
        sellId:
          description: |
            Customer identification number (Sell-ID) from the AutoScout24 CRM system, which is also printed on official dealer invoice/communication documents.
            Note: only the id can be used to make requests.
          type: string
          example: "892611"
        canSetMiaRequestedTier:
          description: |
            If a customer has a contract to use the manualTier feature.
            See MiaPayload section for more information about this feature.
          type: boolean
          example: true
        canUseSellOnline:
          description: |
            If a customer has a contract to use the sellOnline feature.
            <strong>:construction: This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          type: boolean
          example: true
        externalId:
          description: |
            An optional String ID that can be set by customer care to identify the dealer across systems.
          type: string
          example: "1085"

    CustomerSeals:
      properties:
        sealsId:
          type: array
          description: List of seals
          example: [ 1, 2, 3 ]
          uniqueItems: true
          items:
            type: integer
            description: List of seals

    Customers:
      properties:
        customers:
          description: a list of customers
          type: array
          items:
            $ref: '#/components/schemas/Customer'

    DealerPrice:
      allOf:
        - $ref: '#/components/schemas/Price'
        - type: object
          properties:
            netPrice:
              type: integer
              minimum: 1
              description: |
                Net price for the vehicle
                
                > Must be less than <code>price</code>
              example: 15300
            vatRate:
              type: number
              minimum: 0.0
              maximum: 100.0
              description: |
                The value added tax rate.

                > Only 1 decimal is accepted. If more decimals are sent they will be truncated.
              example: 17

    Discount:
      required:
        - priceAlreadyDiscounted
        - fixedAmount
      properties:
        priceAlreadyDiscounted:
          type: boolean
          example: false
          description: |
            Indicates whether a discount is already included in a price / monthly rate.
        fixedAmount:
          type: integer
          description: |
            An amount to be discounted
          example: 500

    ExclusiveOfferPayload:
      required:
        - description
        - endDate
      properties:
        description:
          type: string
          maxLength: 300
          description: |
            A description about the exclusive offer
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: 10% off for the first 10 days.
        endDate:
          type: string
          format: date
          description: |
            A date by which the exclusive offer expires.
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: 2020-09-10

    ExclusiveOffer:
      properties:
        description:
          type: string
          maxLength: 300
          description: |
            A description about the exclusive offer
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: 10% off for the first 10 days.
        endDate:
          type: string
          format: date
          description: |
            A date by which the exclusive offer expires.
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: 2020-09-10

    FallbackAttributesBase:
      required:
        - value
        - sourceTimestamp
      properties:
        value:
          type: number
          example: 85.4
          description: |
            Number value for fallback attributes.
        sourceTimestamp:
          type: string
          format: date-time
          example: 2019-02-07T16:07:00.665267Z
          description: |
            Datetime value for fallback attributes in ISO-8601 format.

    FallbackAttributesInteger:
      required:
        - value
        - sourceTimestamp
      properties:
        value:
          type: integer
          example: 1
          description: |
            Integer value for fallback attributes.
        sourceTimestamp:
          type: string
          format: date-time
          example: 2019-02-07T16:07:00.665267Z
          description: |
            Datetime value for fallback attributes in ISO-8601 format.

    FallbackAttributesConsumption:
      description: |
        Consumption fallback attributes.
      properties:
        combined:
          description: Combined fallback attributes in consumption.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        electricCombined:
          description: Electric combined fallback attributes in consumption.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'

    FallbackAttributesWltp:
      properties:
        co2EmissionsCombined:
          description: |
            Co2 emissions combined fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        co2EmissionsCombinedWeighted:
          description: |
            Co2 emissions combined weighted fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        consumptionCombined:
          description: |
            Consumption combined fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        consumptionElectricCombined:
          description: |
            Consumption electric combined fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        consumptionCombinedWeighted:
          description: |
            Consumption combined weighted fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        consumptionElectricCombinedWeighted:
          description: |
            Consumption electric combined weighted fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        co2Class:
          description: |
            Co2 class fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesInteger'
        consumptionCombinedDischarged:
          description: |
            Consumption combined discharged fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        co2ClassDischarged:
          description: |
            Co2 class discharged fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesInteger'

    FallbackAttributes:
      properties:
        electricRange:
          description: |
            Electric range fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        wltp:
          description: |
            Wltp fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesWltp'
        co2Emissions:
          description: |
            Co2 emissions fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
        consumption:
          description: |
            Consumption fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesConsumption'
        efficiencyClass:
          description: |
            Efficiency class fallback attributes.
          allOf:
            - $ref: '#/components/schemas/FallbackAttributesBase'
    FinancingOffer:
      allOf:
        - $ref: '#/components/schemas/FinancingOfferCommon'
        - type: object
          properties:
            annualRateUnit:
              type: string
              description: Unit used for annualRate field.
              example: "%"
            debitInterestRateUnit:
              type: string
              description: Unit used for debitInterestRate field.
              example: "%"
            durationUnit:
              type: string
              description: Unit used for duration field.
              example: months

    FinancingOfferPayload:
      required: [ annualRate, bank, currency, debitInterestRate, debitInterestType, duration, financingType, grossCreditAmount, monthlyRate, netCreditAmount ]
      allOf:
        - $ref: '#/components/schemas/FinancingOfferCommon'

    FinancingOfferCommon:
      properties:
        annualRate:
          minimum: 0
          maximum: 99.99
          type: number
          description: Annual rate in %.
          example: 10
        bank:
          type: string
          maxLength: 600
          description: |
            Name, legal form, address, postal code and city of bank as well as other financing offer conditions.
            Also indicate whether the financing offer requires the conclusion of an insurance contract or a contract for other supplementary benefits.
            If the cost of this contract cannot be determined in advance, indicate the obligation to conclude this contract
            (e.g. compulsory conclusion of a comprehensive insurance contract)
          example: Mercedes-Benz Bank AG, Siemensstraße 7, 70469 Stuttgart
        bankSecondLanguage:
          type: string
          maxLength: 600
          description: |
            Dealers using EDF (Exclusive Dealer Financing) in Belgium need to fill in an additional "Other Financing Conditions" field.
            Due to legal requirements, text needs to be displayed in French on FR-BE and in Dutch on NL-BE.
            In order to avoid financial consequences, both versions must be filled in.
          example: |
            FR version: Prêt à tempérament tous buts de 8.500 €, TAEG (Taux Annuel Effectif Global) de 5,99% (taux débiteur annuel fixe : 5,99%),
            mensualité de 198,96 € pour une durée de crédit de 48 mois.
            NL version: Lening op afbetaling van € 8.500, JKP (jaarlijks kostenpercentage) van 5,99% (vaste jaarlijkse debetrente: 5,99%),
            maandelijkse aflossing van € 198,96 voor een looptijd van het krediet van 48 maanden.
        closingCosts:
          type: number
          minimum: 0
          maximum: 999999.99
          description: |
            A fee for placing the loan contract.
          example: 250.00
        currency:
          type: string
          enum: [ "EUR" ]
          description: |
            Currency for given financing offer fields.
          example: EUR
        debitInterestType:
          type: integer
          description: |
            Debit interest type.

            > Allowed values can be retrieved via the references API (reference type DebitInterestType).

          example: 1
        debitInterestRate:
          type: number
          minimum: 0
          maximum: 99.99
          description: Debit interest rate in %.
          example: 15
        duration:
          type: integer
          minimum: 1
          maximum: 999
          description: Duration of the loan contract in months.
          example: 3
        endingRate:
          type: number
          description: Ending rate.
          example: 100
          minimum: 0.00
          maximum: 999999.99
        financingType:
          type: string
          description: |
            Financing type.

            > Meaning of the values: <code>C</code> (Credit)

          enum: [ "C" ]
          example: C
        grossCreditAmount:
          type: number
          minimum: 0.01
          maximum: 999999999.99
          description: |
            Gross credit amount in EUR.
          example: 1000
        initialPayment:
          type: number
          minimum: 0.00
          maximum: 999999.99
          description: |
            Initial payment for the loan in EUR (if applicable).
          example: 5000
        monthlyRate:
          type: number
          minimum: 0.00
          maximum: 999999.99
          description: |
            Monthly rate in EUR.
          example: 200
        netCreditAmount:
          type: number
          minimum: 0.00
          maximum: 999999999.99
          description: |
            Net credit amount in EUR.
          example: 19999.9
        paymentProtectionInsurance:
          type: number
          minimum: 0.00
          maximum: 999999999.99
          description: |
            Monthly payment protection insurance rate in EUR.
          example: 100

    Highlight:
      description: |
        A short note highlighting a key feature of the vehicle

        > URLs are forbidden in the content

        > Emails are forbidden in the content

        > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>
      type: string
      maxLength: 30
      minLength: 1
      example: "fully equipped"

    OnlineSale:
      type: object
      description: |
        An object describing the countries where the vehicle can be sold online and delivered to the buyer

        > only available for dealers
        > added to the listing when the customer has a National Listings subscription
      properties:
        deliveryAreas:
          type: object
          description: |
            The countries where the vehicle can be sold online and delivered to the buyer.
          example: |
            {
              "national": "DE"
            }
          properties:
            national:
              type: string
              format: string
              description: Country in which the listing can be delivered
              example: "DE"

    Image:
      required:
        - id
      properties:
        id:
          type: string
          format: guid
          description: The image identifier
          example: 269e6ae5-a49b-4ea5-85a2-9c2093c26287
        previewUrl:
          description: The URL of the image
          type: string
          example: "https://prod.pictures.autoscout24.net/listing-images/d0b91f24-68c2-4683-b575-db510e97fc2d_e5079988-9e05-43f0-8cba-6f37e6f1de28.jpg"
        md5:
          description: The unique MD5 hash identifier for image
          type: string
          example: bb3da223907cbe437bab4cf2e7343d61


    ImagePayload:
      type: object
      required:
        - id
      properties:
        id:
          type: string
          format: guid
          description: The identifier of the image to associate to the listing
          example: 269e6ae5-a49b-4ea5-85a2-9c2093c26287

    ImageReference:
      required:
        - id
      properties:
        id:
          type: string
          format: guid
          description: The image identifier
          example: 269e6ae5-a49b-4ea5-85a2-9c2093c26287

    ImageMd5:
      properties:
        md5:
          description: The unique MD5 hash identifier for image
          type: string
          example: bb3da223907cbe437bab4cf2e7343d61

    ImagePresignedUrl:
      properties:
        imagePresignedUrl:
          description: |
            A pre-signed URL that allows you to grant temporary access to image for users who don't have permission to AWS S3 bucket.
            A pre-signed URL is signed with your credentials and can be used by any user.
          type: string
          example: https://{bucket-name}-{aws-account}-{aws-region}.s3.eu-west-1.amazonaws.com/{imageId}.{format}?{response-content}

    ImageStandard:
      allOf:
        - $ref: '#/components/schemas/ImagePresignedUrl'
        - $ref: '#/components/schemas/ImageReference'

    LeasingOffersPayload:
      required:
        - offers
      properties:
        offers:
          type: array
          description: |
            Allows a dealer to offer leasing when selling the vehicle.

            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          items:
            $ref: '#/components/schemas/LeasingOfferPayload'
        providerId:
          type: string
          description: leasing offers id
          example: 823892

    LeasingOfferPayload:
      required:
        - contractType
        - downPayment
        - netLoanAmount
        - borrowingRate
        - borrowingRateType
        - effectiveInterestRate
        - bank
        - duration
        - includedMileage
        - grossMonthlyRate
        - targetGroup
      allOf:
        - $ref: '#/components/schemas/LeasingOfferCommon'

    LeasingOfferCommon:
      properties:
        referenceOfferId:
          type: string
          description: A reference ID for the leasing offer from the partner.
          example: a100
          minLength: 1
          maxLength: 50
        contractType:
          description: Type of leasing contract
          type: string
          enum: [ "KilometerLeasing" ]
          example: KilometerLeasing
        targetGroup:
          description: Target group
          type: string
          enum: [ "Private","Business","Both" ]
          example: Both
        grossListPrice:
          description: |
            Vehicle list price (gross)

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 139999.95
        isTradeInPossible:
          description: Whether trade-in option is possible
          type: boolean
          example: true
        downPayment:
          description: |
            Downpayment

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 10000.00
        finalInstallment:
          description: |
            Final installment

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 9000.00
        negotiable:
          description: Monthly rate is negotiable
          type: boolean
          example: false
        conditions:
          description: Comments on the conditions around the leasing contract
          type: string
          example: Begrenztes Angebot, nur bis 31.02.2020.
        hasTransferCostsIncluded:
          description: Is the transfer of the vehicle from the manufacturer to the dealer included in the price?
          type: boolean
          minimum: 0
          example: true
        transferCosts:
          description: |
            Total costs for transporting the vehicle from the manufacturer to the dealer and subsequent preparation of the vehicle

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          example: 100.00
        hasRegistrationCostsIncluded:
          description: Is the registration of the vehicle and the license plate included in the price?
          type: boolean
          example: false
        registrationCosts:
          description: |
            Total cost of vehicle registration including license plate number (if requested by the customer).

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 99.00
        leaseTotalAmount:
          description: |
            The total gross amount to be paid by the consumer for the entire term.

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0.01
          example: 77005.60
        netLoanAmount:
          description: |
            Net loan amount

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
            
            > May be set to 0 for LeasingMarkt
          type: number
          minimum: 0.01
          example: 35956.34
        borrowingRate:
          description: |
            Borrowing rate p.a.

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: -100
          maximum: 100
          example: 95.00
        borrowingRateType:
          description: Type of nominal interest rate
          type: string
          enum: [ "Bound", "Changeable", "Combined" ]
          example: Combined
        effectiveInterestRate:
          description: |
            Effective interest rate

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: -100
          maximum: 100
          example: 80.00
        bank:
          description: Leasing bank (full name and address)
          type: string
          example: Volkswagen Bank AG, Römerstr. 145, 04109 Leipzig
          maxLength: 255
          minLength: 1
        refundForLessDistance:
          description: |
            Remuneration for less distance (in cents per kilometer)

            > Forbidden for contract type is not <code>KilometerLeasing</code>

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 4.65
        additionalDistanceCost:
          description: |
            Cost per additional distance (in cents per kilometer)

            > Forbidden if contract type is not <code>KilometerLeasing</code>

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0
          example: 12.65
        dieselEnvironmentalBonus:
          description: Does this offer only apply to customers who will scrap or trade in a diesel vehicle?
          type: boolean
          example: false
        duration:
          description: Term of the contract (in months)
          type: integer
          minimum: 1
          maximum: 90
          example: 48
        includedMileage:
          description: Annual mileage (in km)
          type: integer
          minimum: 0
          example: 15000
        grossMonthlyRate:
          description: |
            Monthly rate (gross)

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0.01
          example: 1395.95
        netMonthlyRate:
          description: |
            Monthly rate (net)

            > Only two decimals are accepted. If more decimals are sent they will be truncated.
          type: number
          minimum: 0.01
          example: 1095.95

    LeasingOffers:
      required:
        - offers
      properties:
        offers:
          type: array
          description: |
            Allows a dealer to offer leasing when selling the vehicle.

            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          items:
            $ref: '#/components/schemas/LeasingOffer'
        providerId:
          type: string
          description: leasing offers id
          example: 823892

    LeasingOffer:
      allOf:
        - $ref: '#/components/schemas/LeasingOfferCommon'
        - type: object
          properties:
            borrowingRateUnit:
              type: string
              description: Unit used for borrowingRate field.
              example: "%"
            effectiveInterestRateUnit:
              type: string
              description: Unit used for effectiveInterestRate field.
              example: "%"
            grossMonthlyRateUnit:
              type: string
              description: Unit used for grossMonthlyRate field.
              example: "EUR"
            netMonthlyRateUnit:
              type: string
              description: Unit used for netMonthlyRate field.
              example: "EUR"
            durationUnit:
              type: string
              description: Unit used for duration field.
              example: "months"
            includedMileageUnit:
              type: string
              description: Unit used for includedMileage field.
              example: "km"

    PartialMiaPayload:
      allOf:
        - type: object
          properties:
            requestedTier:
              type: string
              description: |
                The required tier for the MIA vehicle.
              enum: [ "T20", "T30", "T40" ]
              example: "T30"
            subtitle:
              type: string
              description: |
                The subtitle for the MIA vehicle.
              example: "MIA T30"

    PartialListingBoostPayload:
      allOf:
        - type: object
          properties:
            requested:
              type: boolean
              description: |
                The request required for the listing to become a ListingBoost candidate.
              example: true

    PartialMarketingPayload:
      allOf:
        - type: object
          properties:
            mia:
              description: |
                Provides a manual override for the MIA product for this listing
              allOf:
                - $ref: '#/components/schemas/PartialMiaPayload'
            listingBoost:
              description: |
                Provides a request for this listing to be a ListingBoost candidate
              allOf:
                - $ref: '#/components/schemas/PartialListingBoostPayload'

    ListingPayload:
      required: [ availability, bodyType, make, offerType, publication, prices, vehicleType ]
      allOf:
        - $ref: '#/components/schemas/ListingPayloadSharedAllSellers'
        - $ref: '#/components/schemas/ListingPayloadSharedDealerOnly'
        - type: object
          properties:
            availability:
              description: |
                Provides information about when the vehicle is available.

                > Mandatory for all listings

              allOf:
                - $ref: '#/components/schemas/Availability'
            offerType:
              type: string
              description: |
                Specifies the offer type of the vehicle.

                > Allowed values can be retrieved via the references API (reference type OfferType)


                > Mandatory for all listings
              example: U
            publication:
              description: |
                Provides information about the publication status of the listing

                > Mandatory for all listings
              allOf:
                - $ref: '#/components/schemas/PublicationPayload'
            prices:
              description: |
                Provides price information for the vehicle.

                > Mandatory for all listings
              allOf:
                - $ref: '#/components/schemas/Prices'
            twinner:
              description: Provides Twinner information for the vehicle.
              allOf:
                - $ref: '#/components/schemas/TwinnerPayload'

    PartialListingPayload:
      allOf:
        - $ref: '#/components/schemas/ListingPayloadSharedAllSellers'
        - type: object
          properties:
            crossReferenceId:
              type: string
              description: |
                A reference that can be used when managing or identifying listings.
                This information will not be shown on the AutoScout24 platform.

                > URLs are forbidden in the content


                > Emails are forbidden in the content


                > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>


                > This attribute only applies for customers that are dealers.

              minLength: 1
              maxLength: 50
              example: DATX_002
            warranty:
              type: integer
              minimum: 1
              maximum: 99
              description: |
                Specifies the length in months of an additional warranty that is offered by the dealer.
                This warranty must be included in the vehicle price.
                If this field is not set, no warranty is provided

                > This attribute only applies for customers that are dealers.
              example: 12
            hasWarranty:
              type: boolean
              description: |
                Whether the vehicle has warranty.
                If warranty is set to 0 this can't be set to 'true'
                If warranty is set to > 0 this can't be set to 'false'

                > This attribute only applies for customers that are dealers.
              example: true
            availability:
              description: |
                Provides information about when the vehicle is available.

                > Mandatory for all listings


                > This attribute only applies for customers that are dealers (sellerType='Dealer').

              allOf:
                - $ref: '#/components/schemas/Availability'
            offerType:
              type: string
              description: |
                Specifies the offer type of the vehicle.

                > Allowed values can be retrieved via the references API (reference type OfferType)


                > Allowed values for dealers (sellerType='Dealer'): [ Active, Inactive ]


                > Allowed values for private sellers (sellerType='Private'): [ Active, Inactive, Draft ]


                > Mandatory for all listings

              example: U
            publication:
              description: |
                Provides information about the publication status of the listing

                > Mandatory for all listings
              allOf:
                - $ref: '#/components/schemas/PublicationPayload'
            prices:
              description: |
                Provides price information for the vehicle.

                > Mandatory for all listings
              allOf:
                - $ref: '#/components/schemas/Prices'
            requestedSeals:
              description: |
                List of IDs for the used vehicle seals granted for the vehicle.
                Available values for the customer can be retrieved using the getSealsForCustomer operation.

                <strong>Note:</strong> If passed seals are not granted with vehicle, the system will ignore those values and create the listings.

                > This attribute only applies for customers that are dealers.

              type: array
              example: [ 1, 2, 3 ]
              uniqueItems: true
              items:
                type: integer
            sealsOverwriteProtection:
              description: |
                It can be only set by dealers logging in through MLC. If set to true, the seals will not be overwritten with any update request from data providers.
              type: boolean
              example: true
            twinner:
              description: Provides Twinner information for the vehicle.
              allOf:
                - $ref: '#/components/schemas/TwinnerPayload'

    ListingPayloadSharedDealerOnly:
      type: object
      properties:
        crossReferenceId:
          type: string
          description: |
            A reference that can be used when managing or identifying listings.
            This information will not be shown on the AutoScout24 platform.

            > URLs are forbidden in the content


            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>


            > This attribute only applies for customers that are dealers.

          minLength: 1
          maxLength: 50
          example: DATX_002
        leasingOffers:
          description: |
            Allows a dealer to offer leasing when selling the vehicle.

            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/LeasingOffersPayload'
        warranty:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Specifies the length in months of an additional warranty that is offered by the dealer.
            This warranty must be included in the vehicle price.
            If this field is not set, no warranty is provided

            > This attribute only applies for customers that are dealers.
          example: 12
        hasWarranty:
          type: boolean
          description: |
            Whether the vehicle has warranty.
            If warranty is set to 0 this can't be set to 'true'
            If warranty is set to > 0 this can't be set to 'false'

            > This attribute only applies for customers that are dealers.
          example: true
        financingOffer:
          description: |
            Allows a dealer to offer financing when selling the vehicle.
            The financing offer will only be shown if the dealer has a contract to use this feature


            > This attribute only applies for customers that are dealers.

          allOf:
            - $ref: '#/components/schemas/FinancingOfferPayload'
        marketing:
          description: |
            Provides additional marketing information


            > This attribute only applies for customers that are dealers.

          allOf:
            - $ref: '#/components/schemas/MarketingPayload'
        requestedSeals:
          description: |
            List of IDs for the used vehicle seals granted for the vehicle.
            Available values for the customer can be retrieved using the getSealsForCustomer operation.

            <strong>Note:</strong> If passed seals are not granted with vehicle, the system will ignore those values and create the listings.

            > This attribute only applies for customers that are dealers.

          type: array
          example: [ 1, 2, 3 ]
          uniqueItems: true
          items:
            type: integer
        highlights:
          description: |
            Short notes highlighting key features of the vehicle

            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>


            > This attribute only applies for customers that are dealers.

          type: array
          maxItems: 3
          items:
            $ref: '#/components/schemas/Highlight'
        sealsOverwriteProtection:
          description: |
            It can be only set by dealers logging in through MLC. If set to true, the seals will not be overwritten with any update request from data providers.
          type: boolean
          example: true

    ListingPayloadSharedDealerOnlyNoMarketing:
      type: object
      properties:
        crossReferenceId:
          type: string
          description: |
            A reference that can be used when managing or identifying listings.
            This information will not be shown on the AutoScout24 platform.

            > URLs are forbidden in the content


            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>


            > This attribute only applies for customers that are dealers.

          minLength: 1
          maxLength: 50
          example: DATX_002
        leasingOffers:
          description: |
            Allows a dealer to offer leasing when selling the vehicle.

            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/LeasingOffersPayload'
        warranty:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Specifies the length in months of an additional warranty that is offered by the dealer.
            This warranty must be included in the vehicle price.
            If this field is not set, no warranty is provided

            > This attribute only applies for customers that are dealers.
          example: 12
        hasWarranty:
          type: boolean
          description: |
            Whether the vehicle has warranty.
            If warranty is set to 0 this can't be set to 'true'
            If warranty is set to > 0 this can't be set to 'false'

            > This attribute only applies for customers that are dealers.
          example: true
        financingOffer:
          description: |
            Allows a dealer to offer financing when selling the vehicle.
            The financing offer will only be shown if the dealer has a contract to use this feature


            > This attribute only applies for customers that are dealers.

          allOf:
            - $ref: '#/components/schemas/FinancingOfferPayload'
        requestedSeals:
          description: |
            List of IDs for the used vehicle seals granted for the vehicle.
            Available values for the customer can be retrieved using the getSealsForCustomer operation.

            <strong>Note:</strong> If passed seals are not granted with vehicle, the system will ignore those values and create the listings.

            > This attribute only applies for customers that are dealers.

          type: array
          example: [ 1, 2, 3 ]
          uniqueItems: true
          items:
            type: integer
        sealsOverwriteProtection:
          description: |
              It can be only set by dealers logging in through MLC. If set to true, the seals will not be overwritten with any update request from data providers.
          type: boolean
          example: true
        highlights:
          description: |
            Short notes highlighting key features of the vehicle

            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>


            > This attribute only applies for customers that are dealers.

          type: array
          maxItems: 3
          items:
            $ref: '#/components/schemas/Highlight'

    BasePayloadShared:
      type: object
      properties:
        additionalFuelTypes:
          type: array
          description: |
            Additional supported fuel types that might accompany the primary fuel type.
            These fuel types can also be consumed by the vehicle but have higher emissions than the primary fuel type.
            This is derived from German emission/consumption regulations for vehicles (EnVKV).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Optional for vehicleType  <code>C</code> (Car), <code>X</code> (light commercial vehicle), <code>B</code> (bikes), <code>N</code> (caravan/mobile home)

          uniqueItems: true
          example: [ 2, 3 ]
          items:
            type: integer
            description: |
              Each of the fuel type identifiers. Allowed values can be retrieved via the references API
              (reference type FuelType)
        alloyWheelSize:
          type: integer
          minimum: 10
          maximum: 26
          description: |
            Size of alloy wheels of the vehicle (in inches).

            > This property can only be specified if the equipment <code>15 "Alloy Wheels"</code> is set in the equipment property.

          example: 18
        axleCount:
          type: integer
          description: |
            The number of axles the vehicle has.

            > Forbidden for vehicleType <code>C</code> (car) and <code>B</code> (bike)

          minimum: 1
          maximum: 6
          example: 1
        bedCount:
          type: integer
          description: |
            Total number of beds.

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike), <code>X</code> (light commercial vehicle) and <code>L</code> (trailer)

          minimum: 0
          maximum: 9
          example: 4
        belgianCarpassMileageUrl:
          type: string
          format: url
          description: |
            The URL for the Carpass technical inspection for the listed vehicle

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: "https://public.car-pass.be/vhr/2a0f0719-1b7a-4e42-84e1-c5c746ab1c39"
        bodyColor:
          type: integer
          description: |
            Basic body color of the vehicle.
            > Allowed values can be retrieved via the references API (reference type BodyColor).
          example: 2
        bodyColorName:
          type: string
          minLength: 1
          maxLength: 30
          description: |
            Manufacturers name of body color.

            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>


            >  Strings longer than 30 characters are accepted by the API but will be truncated to 30 characters.

          example: British Racing Green
        bodyType:
          type: integer
          description: |
            Shape of vehicle’s body.

            > Allowed values can be retrieved via the references API (reference type BodyType)

            > Mandatory for all listings

          example: 1
        countryVersion:
          type: string
          description: |
            Indicates the original market/country the vehicle was built for.

            > Allowed values can be retrieved via the references API (reference type Country)

          example: AT
        co2Emissions:
          type: integer
          description: |
            Vehicle’s carbon dioxide emission in g/km.
            
            > *Deprecated, use <code>wltp.co2EmissionsCombined</code> or <code>wltp.co2EmissionsCombinedWeighted</code> instead*

            > Mandatory and not smaller than 1 for German dealers when the car is considered new (<code>mileage</code> <= 1000)

            > Forbidden for vehicleType <code>L</code> (trailer)
          example: 23
        consumption:
          description: |
            Provides fuel and electric consumption information for the vehicle.

            > *Deprecated, use <code>wltp.consumptionCombined</code> or <code>wltp.consumptionCombinedWeighted</code> instead*

            > Forbidden for vehicleType <code>L</code> (trailer)

          allOf:
            - $ref: '#/components/schemas/Consumption'
        cylinderCapacity:
          type: integer
          minimum: 1
          maximum: 99999
          description: |
            Volume of the engines cylinders in cubic centimeters.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 1998
        cylinderCount:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            The number of cylinders of the engine.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 4
        description:
          type: string
          maxLength: 10000
          description: |
            Free text description of the vehicle.

            > Text may be formatted by tags. The following tags are supported:


            > Line break: <code>\n</code> equivalent to HTML's <code>&lt;br&gt;</code>.


            > Horizontal line: <code>----</code>  equivalent to HTML's <code>&lt;hr&gt;</code> and always accompanied by an automatic line break.


            > Bold: <code>**lorem ipsum**</code> equivalent to HTML's <code>&lt;b&gt;lorem ipsum&lt;/b&gt;</code>


            > Bulleted list: <code>\\\\* lorem \\\\* ipsum</code>


            > Note that the first 10000 characters are displayed. Generally 1 character is equal to 1 byte but characters from the extended alphabet like “ä” count as 2 bytes.

          example: |
            This car is **great**. ---- It has the following features: \n \\\\* Low price \\\\* Great interior
        doorCount:
          type: integer
          minimum: 1
          maximum: 9
          description: |
            Number of doors the vehicle has

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 5
        drivetrain:
          type: string
          description: |
            Drive type of the vehicle.

            > Allowed values can be retrieved via the references API (reference type DriveType)


            > Forbidden for vehicleType <code>B</code> (bike) and <code>L</code> (trailer)

          example: R
        efficiencyClass:
          type: integer
          description: |
            Vehicle’s energy efficiency class.

            > *Deprecated, use <code>wltp.co2Class</code> instead*

            > Allowed values can be retrieved via the references API (reference type EfficiencyClass)

            > Mandatory for German dealers when vehicleType is <code>C</code> and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>B</code> (bike) and <code>L</code> (trailer)

          example: 2
        electricRange:
          type: integer
          minimum: 1
          maximum: 10000
          example: 620
          description: |
            The electric range of the vehicle in kilometers according to WLTP. (EAER)

            > Mandatory for German dealers when the consumption values are WLTP and the vehicle type is <code>C</code> (Car), <code>primaryFuelType</code> is <code>12</code> (electric / PHEV / EV) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).
        electricRangeCity:
          type: integer
          minimum: 1
          maximum: 10000
          example: 410
          description: |
            The electric range of the vehicle in kilometers according to WLTP measured in cities. (EAER city)
        emptyWeight:
          type: integer
          minimum: 1
          maximum: 99999
          description: Vehicle’s weight without driver, passengers or liquids (like fuel) in kg.
          example: 1200
        equipment:
          type: array
          description: |
            List of vehicle’s equipment.

            > Allowed values can be retrieved via the references API (reference type equipment)

            > You are only allowed to send one Automatic Climate Control equipment for a given listing. Automatic climate control equipments include: (241) Automatic climate control 2 zones, (242) Automatic climate control 3 zones, (243) Automatic climate control, 4 zones and (30) Automatic climate control. If the vehicle has Automatic Climate Control but the number of zones is unknown, use (30) Automatic climate control.

            > If the vehicle has a sliding door, but the side which the door is on is unknown use equipment (152) Sliding Door. If the side is known use (244) Sliding Door left, (245) Sliding Door right or both (if there are sliding doors on both sides). You are not allowed to send (152) sliding door, and (244)/(245) at the same time.

          example: [ 1, 2, 4, 15 ]
          uniqueItems: true
          items:
            type: integer
            description: |
              An equipment ID.
        euEmissionStandard:
          type: string
          description: |
            The EU emission standard indicates the amount of harmful substances the vehicle emits.
            The classification is in accordance with the European Standard Euronorm

            > Allowed values can be retrieved via the references API (reference type EuEmissionStandard)


            > Forbidden for vehicleType <code>L</code> (trailer)

          example: "1"
        externalCustomerId:
          type: string
          description: A customer id belonging to an external system.
          example: '1'
        firstRegistrationDate:
          type: string
          format: year-month
          description: |
            Month and year of first registration of the vehicle.

            > Mandatory for vehicleType <code>C</code> (car), <code>B</code> (Bike), <code>X</code> (light commercial vehicle) where offerType is  <code>J</code> (employee’s car), <code>O</code> (antique/classic), <code>S</code> (pre-registered), <code>U</code> (used)


            > Must not be more than 24 months in the past  when vehicleType is <code>C</code> (car) and offerType = <code>J</code> (employee’s car)


            > Must not be more than 12 months in the past when vehicleType is <code>C</code> (car) and OfferType = <code>S</code> (pre-registered).  This rule does not apply to Italian dealers


            > Must be greater than 360 months (30 years) when vehicleType is <code>C</code> (car) and offerType is <code>O</code> (antique/classic)


            > Must not be a date from the future set when OfferType = <code>J</code> (annual car) or OfferType = <code>O</code> (old timer).

            > Note: Must not be less than <code>1886</code>

          example: 2015-01
        fuelCategory:
          type: string
          description: |
            Category of fuel/energy source for the vehicle.

            > Allowed values can be retrieved via the references API (reference type FuelCategory)

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: B
        gearCount:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Number of gears of the vehicle

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 6
        germanEmissionsSticker:
          type: integer
          description: |
            Emissions sticker type as assigned by German technical inspection authorities (Umweltplakette/Feinstaubplakette).

            > Allowed values can be retrieved via the references API (reference type EmissionsSticker)


            > Forbidden for vehicleType <code>B</code> (bike) and <code>L</code> (trailer)

          example: 1
        hasCarRegistration:
          type: boolean
          description: |
            Indicates whether a vehicle is registered as a car in the registration documents

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>L</code> (trailer)

          example: false
        hasFullServiceHistory:
          type: boolean
          description: |
            Indicates whether vehicle has passed all periodic maintenance as recommended by the vehicle manufacturer.
          example: false
        hasParticleFilter:
          type: boolean
          description: |
            Indicates whether a diesel vehicle is equipped with a particle filter

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: true
        hsn:
          type: string
          minLength: 4
          maxLength: 4
          description: |
            Herstellerschluesselnummer, or the unique identifier of vehicle manufacturer in Germany.
            In combination with TSN this key is used to uniquely identify a vehicle type.
            The make of a vehicle can be fully derived from this identifier.
          example: "0583"
        includedServices:
          type: array
          uniqueItems: true
          description: |
            Included services as part of the vehicle offer.
            Values <code>1</code> for German dealers (HU/AU) and <code>2</code> for Dutch dealers indicate that an inspection has been done recently and the vehicle is in a roadworthy state.

            > Allowed values can be retrieved via the references API (reference type IncludedService).

          items:
            type: integer
            description: |
              An included service ID.
          example: [ 1, 2 ]
        isMetallic:
          type: boolean
          description: |
            Whether the vehicle’s body color has a metallic effect.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: true
        isNonSmoking:
          type: boolean
          description: |
            Whether the vehicle has been used by non-smokers only.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: true
        isPluginHybrid:
          type: boolean
          description: |
            Whether the vehicle is a plugin hybrid.

            > If this property is set to <code>true</code>, then:

            > <code>primaryFuelType</code> OR <code>additionalFuelTypes</code> must contain <code>12</code> (Electric) AND <code>primaryFuelType</code> OR <code>additionalFuelTypes</code> must contain one fuel type != <code>12</code> (Electric)</li>

            > <code>fuelCategory</code> must be one of <code>3</code> (Electric/Diesel), <code>2</code> (Electric/Benzin) or <code>O</code> Others</li>
          example: true
        lastCamBeltServiceDate:
          type: string
          format: year-month
          description: |
            Date of last cam belt exchange.
            Cannot be in the future.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 2016-01
        lastTechnicalServiceDate:
          type: string
          format: year-month
          description: Date of last periodic maintenance
          example: 2016-06
        licencePlate:
          type: string
          minLength: 1
          maxLength: 10
          description: |
            Licence plate number of the vehicle

            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>

          example: M-2411-DC
        make:
          type: integer
          description: |
            Make identifier of the vehicle.

            > Allowed values can be retrieved via the makes API


            > Mandatory for all listings

          example: 13
        model:
          type: integer
          description: |
            The model of the vehicle (for cars and bikes)

            > Allowed values can be retrieved via the makes API


            > Mandatory for vehicleType <code>C</code> (car) and <code>B</code> (bike)


            > Forbidden for vehicleType <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)

          example: 1641
        modelName:
          type: string
          maxLength: 50
          example: Sprinter 310 Carlsen
          description: |
            The model of the vehicle (for Light Commercial Vehicles, Trailers, Caravans/Mobile homes)

            > Mandatory for vehicleType <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)


            > Forbidden for vehicleType <code>C</code> (car) and <code>B</code> (bike)

        modelVersion:
          type: string
          minLength: 1
          maxLength: 50
          description: |
            Additional information about the model.

            > Forbidden for vehicleType <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)


            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>


            > Strings longer than 50 characters are accepted by the API but will be truncated to 50 characters.

          example: Avant
        nextInspectionDate:
          type: string
          format: year-month
          description: |
            Date of next technical inspection as required by regulations.

            > Must be within the next 5 years, or in the past 5 years.

          example: 2019-01
        offerReferenceId:
          type: string
          description: |
            A reference ID for the vehicle that can be used by buyers.
            Will be shown on the AutoScout24 plaform

            > URLs are forbidden in the content


            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>

          example: A12453
          minLength: 1
          maxLength: 50
        power:
          type: integer
          minimum: 1
          maximum: 9999
          description: |
            Engine power in kW. Power in (German) PS does not need to be specified, as it will automatically be derived from this value.

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 110
        previousOwnerCount:
          type: integer
          minimum: 0
          maximum: 99
          description: |
            Number of previous vehicle owners.

          example: 1
        primaryFuelType:
          type: integer
          description: |
            Fuel type with the lowest emission for the vehicle. This is derived from German emission/consumption regulations for vehicles (EnVKV).

            > Allowed values can be retrieved via the references API (reference type FuelType).

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)
          example: 1
        productionYear:
          type: string
          description: |
            The year when the vehicle was manufactured.
          example: "2014"
        seatCount:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Number of seats of the vehicle

            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 5
        transmission:
          type: string
          description: |
            Specifies the transmission type of the vehicle (e.g. manual, automatic).

            > Allowed values can be retrieved via the references API (reference type Transmission).


            > Forbidden for vehicleType <code>L</code> (trailer)

          example: "M"
        totalHeight:
          type: integer
          description: |
            Height of the vehicle in mm. Only available when vehicleType is <code>N</code>.

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike), <code>X</code> (light commercial vehicle) and <code>L</code> (trailer)

          example: 200
          minimum: 1
        totalLength:
          type: integer
          description: |
            Length of the vehicle in mm. Only available when vehicleType is <code>N</code>.

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike), <code>X</code> (light commercial vehicle) and <code>L</code> (trailer)

          example: 200
          minimum: 1
        totalWidth:
          type: integer
          description: |
            Width of the vehicle in mm. Only available when vehicleType is <code>N</code>

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike), <code>X</code> (light commercial vehicle) and <code>L</code> (trailer)

          example: 200
          minimum: 1
        tsn:
          type: string
          minLength: 3
          maxLength: 3
          description: |
            Typschluesselnummer: Identifier used by vehicle manufacturers in Germany to specify a vehicle type.
            From TSN the following parameters can be derived: Model, body, engine type, fuel type etc.
            Combined with HSN a make/model combination can be fully specified.
          example: "936"
        upholsteryColor:
          type: integer
          description: |
            Basic color of vehicle’s interior. Used to enable search by basic interior color.

            > Allowed values can be retrieved via the references API (reference type InteriorColor)


            > Forbidden for vehicleType <code>L</code> (trailer)

          example: 1
        upholsteryType:
          type: string
          description: |
            The type of upholstery the vehicle has

            > Allowed values can be retrieved via the references API (reference type Upholstery)


            > Forbidden for vehicleType <code>L</code> (trailer)

          example: "AL"
        vehicleType:
          description: |
            The type of vehicle being listed.

            > Mandatory for all listings

          allOf:
            - $ref: '#/components/schemas/VehicleTypeId'
        vin:
          type: string
          minLength: 17
          maxLength: 17
          description: |
            Vehicle Identification Number. A unique international code including a serial number used to identify individual motor vehicles, towed vehicles and motorcycles

            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>

          example: AB023475861123745
        wasCabOrRental:
          type: boolean
          description: |
            Whether the vehicle has been used as cab or rental car.

            > Forbidden for vehicleType <code>B</code> (bike), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)

          example: false
        wheelbase:
          type: integer
          description: |
            The distance between the centers of the front and rear wheels, measured in millimeters.

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>L</code> (trailer)

          minimum: 1
          example: 2800
        youtubeVideoUrl:
          type: string
          format: url
          minLength: 1
          maxLength: 256
          description: |
            Youtube video for the vehicle.
            Videos from other platforms other than Youtube are not accepted

            > Must be a YouTube URL

          example: "https://www.youtube.com/watch?v=wnKJnWRa_Ks"
        grossVehicleWeight:
          type: integer
          description: |
            The maximum operating weight of a vehicle measured in kg, including its chassis, body, engine, engine fluids, fuel, accessories, driver, passengers and cargo

            > Forbidden for vehicleType <code>C</code> (car) and <code>B</code> (bike)

          minimum: 1
          example: 3500
        images:
          type: array
          description: |
            The images to associate with this listing.
            It will fully replace the previous associated images.
            Orphan images will be deleted immediately after the operation.
          uniqueItems: true
          items:
            $ref: '#/components/schemas/ImagePayload'
          maxItems: 50
          example:
            - id: 269e6ae5-a49b-4ea5-85a2-9c2093c26287
            - id: 84c7df0f-6806-4d07-b667-cb7ed5109a61
        loadHeight:
          type: integer
          description: |
            Maximum height of the load in millimeters

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)

          minimum: 1
          example: 1900
        loadLength:
          type: integer
          description: |
            Maximum length of the load in millimeters

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)

          minimum: 1
          example: 3800
        loadVolume:
          type: number
          description: |
            Maximum volume of the load in cubic meters

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)

          example: 5.5
        loadWidth:
          type: integer
          description: |
            Maximum width of the load in millimeters

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)

          minimum: 1
          example: 2100
        maximumTowingWeight:
          type: integer
          description: |
            The maximum weight the vehicle can tow in kg.

            > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>L</code> (trailer)

          minimum: 1
          example: 130
        mileage:
          type: integer
          description: |
            The distance in kilometers that the vehicle has run.

            > Mandatory, and must be greater or equal than 0 when offerType is <code>J</code> (employee’s car), <code>S</code> (pre-registered), <code>O</code> (antique/classic), <code>U</code> (used) when vehicleType is C (car), B (bike) or X (light commercial vehicle)

            > Optional for vehicleType <code>N</code> (caravan/mobile home)

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Mileage must be less than 1000 when offerType is <code>N</code> (new)

          example: 75000
        payload:
          type: integer
          description: |
            Maximum payload the vehicle can carry in kg.

            > Forbidden for vehicleType <code>C</code> (car) and <code>B</code> (bike)

          minimum: 0
          example: 2900
        condition:
          description: |
            Describes the current condition of the vehicle
          allOf:
            - $ref: '#/components/schemas/Condition'
        battery:
          description: Information about the vehicle's battery
          allOf:
            - $ref: '#/components/schemas/BatteryPayload'
        wltp:
          description: |
            Provides WLTP consumption information.
            
            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
          allOf:
            - $ref: '#/components/schemas/WltpCommon'
        costModel:
          description: |
            Provides information about the costs associated with the vehicle.
            
            > This attribute only applies for customers that are dealers.

          allOf:
            - $ref: '#/components/schemas/CostModelPayload'

    ListingPayloadSharedAllSellers:
      allOf:
        - $ref: '#/components/schemas/BasePayloadShared'
        - type: object
          properties:
            isReserved:
              type: boolean
              description: |
                Whether the vehicle is reserved.
                
                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            isEUReimport:
              type: boolean
              description: |
                Whether the vehicle is EU reimported.
                
                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            smyleVisibility:
              type: string
              description: |
                Visibility configuration for smyle listing. Set this field if this is a smyle listing and also you want to change the default visibility.
                Options:
                 - AS24: Show this listing only on the AS24 platform
                 - SMYLE: Show this listing only on the Smyle platform
                 - BOTH (default): Show this listing on both AS24 and SMYLE platforms.
                
                > This attribute is only available for Smyle listings.
              enum: [ "AS24", "SMYLE", "BOTH" ]
              example: "BOTH"
            images:
              type: array
              description: |
                The images to associate with this listing.
                It will fully replace the previous associated images.
                Orphan images will be deleted immediately after the operation.
              uniqueItems: true
              items:
                $ref: '#/components/schemas/ImagePayload'
              maxItems: 50
              example:
                - id: 269e6ae5-a49b-4ea5-85a2-9c2093c26287
                - id: 84c7df0f-6806-4d07-b667-cb7ed5109a61
            schwackeCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
                > *Deprecated, use <code>natCode</code> instead*
              type: string
              maxLength: 22
              example: '20239429'
            europalletStorageSpaces:
              description: |
                The number of europallets that can be transported by the vehicle.
                
                > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)
              type: integer
              example: 5
            drivingMode:
              type: string
              description: |
                The drive type of the bike. Possible values are ChainDrive, BeltDrive, CrankDrive.
                
                > Forbidden for vehicleType <code>C</code> (car), <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)
              enum: [ "ChainDrive", "BeltDrive", "CrankDrive" ]
              example: "ChainDrive"
            firstModelsProductionDate:
              description: |
                The date in which the first models of this vehicle were produced
              type: string
              format: year-month
              example: 2015-02
            marketing:
              description: |
                Provides additional marketing information
                
                
                > This attribute only applies for customers that are dealers.

              allOf:
                - $ref: '#/components/schemas/PartialMarketingPayload'
            natCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
              type: string
              maxLength: 22
              example: '20239429'

    ListingPayloadSharedAllSellersNoMarketing:
      allOf:
        - $ref: '#/components/schemas/BasePayloadShared'
        - type: object
          properties:
            isReserved:
              type: boolean
              description: |
                Whether the vehicle is reserved.
                
                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            isEUReimport:
              type: boolean
              description: |
                Whether the vehicle is EU reimported.
                
                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            smyleVisibility:
              type: string
              description: |
                Visibility configuration for smyle listing. Set this field if this is a smyle listing and also you want to change the default visibility.
                Options:
                 - AS24: Show this listing only on the AS24 platform
                 - SMYLE: Show this listing only on the Smyle platform
                 - BOTH (default): Show this listing on both AS24 and SMYLE platforms.
                
                > This attribute is only available for Smyle listings.
              enum: [ "AS24", "SMYLE", "BOTH" ]
              example: "BOTH"
            schwackeCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
                > *Deprecated, use <code>natCode</code> instead*
              type: string
              maxLength: 22
              example: '20239429'
            firstModelsProductionDate:
              description: |
                The date in which the first models of this vehicle were produced
              type: string
              format: year-month
              example: 2015-02
            europalletStorageSpaces:
              description: |
                The number of europallets that can be transported by the vehicle.
                
                > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)
              type: integer
              example: 5
            drivingMode:
              type: string
              description: |
                The drive type of the bike. Possible values are ChainDrive, BeltDrive, CrankDrive.
                
                > Forbidden for vehicleType <code>C</code> (car), <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)
              enum: [ "ChainDrive", "BeltDrive", "CrankDrive" ]
              example: "ChainDrive"
            vehicleId:
              description: |
                The vehicle identifier.
                
                > This attribute is only available for listings linked to a vehicle. It's the same as the listingId of the vehicle.
              type: string
              example: "v_d9d0b32c-5931-11ee-8c99-0242ac120002"
            natCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
              type: string
              maxLength: 22
              example: '20239429'


    Listing:
      allOf:
        - $ref: '#/components/schemas/ListingSharedAllSellers'
        - $ref: '#/components/schemas/ListingSharedDealerOnly'
        - type: object
          properties:
            offerType:
              type: string
              description: |
                Specifies the offer type of the vehicle.
                Allowed values can be retrieved via the references API (reference type OfferType)
              example: U
            prices:
              description: Provides price information for the vehicle.
              allOf:
                - $ref: '#/components/schemas/Prices'
            publication:
              description: Provides information about the publication status of the listing.
              allOf:
                - $ref: '#/components/schemas/Publication'
            twinner:
              description: Provides Twinner information for the vehicle.
              allOf:
                - $ref: '#/components/schemas/TwinnerPayload'



    ListingSharedDealerOnly:
      type: object
      properties:
        autoproff:
          description: |
            Provides autoproff-related data for the listing. Can not be set by data providers.
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/Autoproff'
        availability:
          description: |
            Provides information about when the vehicle is available.
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/Availability'
        financingOffer:
          description: |
            Provides information about the financing offer of the listing
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/FinancingOffer'
        highlights:
          type: array
          maxItems: 3
          description: |
            Short notes highlighting key features of the vehicle
            
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
            
            > This attribute only applies for customers that are dealers.
          items:
            $ref: '#/components/schemas/Highlight'
        warranty:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Specifies the length in months of an additional warranty that is offered by the dealer.
            This warranty must be included in the vehicle price.
            If this field is not set, no warranty is provided
            
            > This attribute only applies for customers that are dealers.
          example: 12
        warrantyUnit:
          type: string
          description: |
            Unit used for warranty field.
            
            > This attribute only applies for customers that are dealers.
          example: Months
        hasWarranty:
          type: boolean
          description: |
            Whether the vehicle has warranty.
            If warranty is set to 0 this can't be set to 'true'
            If warranty is set to > 0 this can't be set to 'false'
            
            > This attribute only applies for customers that are dealers.
          example: true
        marketing:
          description: |
            Provides additional marketing information
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/Marketing'
        appliedSeals:
          description: |
            List of applied car seals shown on the listing.
            Sometimes additional seals are added or removed automatically, irrespective of the seals set using the <code>requestedSeals</code> property
            Note: this attribute is set for informational purposes as part of our read-only endpoints.
            Please use <code>requestedSeals</code> if you want to submit seals instead.
            
            > This attribute only applies for customers that are dealers.
          type: array
          example: [ 1, 2, 3 ]
          uniqueItems: true
          items:
            type: integer
        leasingOffers:
          description: |
            Allows a dealer to offer leasing when selling the vehicle.
            
            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/LeasingOffers'
        overwriteProtection:
          description: |
            When overwriteProtection is true, it’s not possible to edit or delete the listing using the API.
            Changes or deletions are only possible on the listing using the dealers My Area on the website.
            The dealer can also deactivate this option through My Area.
            A missing value is equivalent to false.
            
            > This attribute only applies for customers that are dealers.
          type: boolean
          example: false
        onlineSale:
          description: |
            Provides information about the online sale of the listing.
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/OnlineSale'

    ListingSharedDealerNoMarketing:
      type: object
      properties:
        autoproff:
          description: |
            Provides autoproff-related data for the listing. Can not be set by data providers.
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/Autoproff'
        availability:
          description: |
            Provides information about when the vehicle is available.
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/Availability'
        financingOffer:
          description: |
            Provides information about the financing offer of the listing
            
            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/FinancingOffer'
        highlights:
          type: array
          maxItems: 3
          description: |
            Short notes highlighting key features of the vehicle
            
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
            
            > This attribute only applies for customers that are dealers.
          items:
            $ref: '#/components/schemas/Highlight'
        warranty:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Specifies the length in months of an additional warranty that is offered by the dealer.
            This warranty must be included in the vehicle price.
            If this field is not set, no warranty is provided
            
            > This attribute only applies for customers that are dealers.
          example: 12
        warrantyUnit:
          type: string
          description: |
            Unit used for warranty field.
            
            > This attribute only applies for customers that are dealers.
          example: Months
        hasWarranty:
          type: boolean
          description: |
            Whether the vehicle has warranty.
            If warranty is set to 0 this can't be set to 'true'
            If warranty is set to > 0 this can't be set to 'false'
            
            > This attribute only applies for customers that are dealers.
          example: true
        appliedSeals:
          description: |
            List of applied car seals shown on the listing.
            Sometimes additional seals are added or removed automatically, irrespective of the seals set using the <code>requestedSeals</code> property
            Note: this attribute is set for informational purposes as part of our read-only endpoints.
            Please use <code>requestedSeals</code> if you want to submit seals instead.
            
            > This attribute only applies for customers that are dealers.
          type: array
          example: [ 1, 2, 3 ]
          uniqueItems: true
          items:
            type: integer
        sealsOverwriteProtection:
          description: |
            When sealsOverwriteProtection is true, it’s not possible to edit or delete the seals using the API.
            Changes or deletions are only possible on the listing from MLC.
            The dealer can also deactivate this option through MLC.
            
            > This attribute only applies for customers that are dealers.
          type: boolean
          example: false
        leasingOffers:
          description: |
            Allows a dealer to offer leasing when selling the vehicle.
            
            > Not available for dealers outside germany. This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/LeasingOffers'
        overwriteProtection:
          description: |
            When overwriteProtection is true, it’s not possible to edit or delete the listing using the API.
            Changes or deletions are only possible on the listing using the dealers My Area on the website.
            The dealer can also deactivate this option through My Area.
            A missing value is equivalent to false.
            
            > This attribute only applies for customers that are dealers.
          type: boolean
          example: false
        onlineSale:
          description: |
            Provides information about the online sale of the listing.

            > This attribute only applies for customers that are dealers.
          allOf:
            - $ref: '#/components/schemas/OnlineSale'


    BaseSharedAllSellersNoImages:
      type: object
      required:
        - id
        - make
        - vehicleType
      properties:
        id:
          type: string
          format: guid
          description: |
            The unique identifier of the listing

            > Mandatory for all listings

          example: cf04da2d-9c57-4758-8735-5257e4eb1cae
        condition:
          description: Describes the current condition of the vehicle
          allOf:
            - $ref: '#/components/schemas/Condition'
        crossReferenceId:
          type: string
          description: |
            A reference that can be used when managing or identifying listings.
            This information will not be shown on the AutoScout24 platform.
          minLength: 1
          maxLength: 50
          example: DATX_002
        additionalFuelTypes:
          type: array
          description: |
            Additional supported fuel types that might accompany the primary fuel type.
            These fuel types can also be consumed by the vehicle but have higher emissions than the primary fuel type.
            This is derived from German emission/consumption regulations for vehicles (EnVKV).
          uniqueItems: true
          example: [ 2, 3 ]
          items:
            type: integer
            description: |
              Each of the fuel type identifiers. Allowed values can be retrieved via the references API
              (reference type FuelType)
        alloyWheelSize:
          type: integer
          minimum: 10
          maximum: 26
          description: |
            Size of alloy wheels of the vehicle (in inches).
          example: 18
        axleCount:
          type: integer
          description: |
            The number of axles the vehicle has.
          minimum: 1
          maximum: 6
          example: 1
        battery:
          description: Information about the vehicle's battery
          allOf:
            - $ref: '#/components/schemas/Battery'
        bedCount:
          type: integer
          description: |
            Total number of beds.
          example: 4
          minimum: 0
        belgianCarpassMileageUrl:
          type: string
          format: url
          description: |
            The URL for the Carpass technical inspection for the listed vehicle
          example: "https://public.car-pass.be/vhr/2a0f0719-1b7a-4e42-84e1-c5c746ab1c39"
        bodyColor:
          type: integer
          description: |
            Basic body color of the vehicle.
          example: 2
        bodyColorName:
          type: string
          minLength: 1
          maxLength: 30
          description: Manufacturers name of body color
          example: British Racing Green
        bodyType:
          type: integer
          description: |
            Shape of vehicle’s body.
          example: 1
        countryVersion:
          type: string
          description: |
            Indicates the original market/country the vehicle was built for.
          example: AT
        co2Emissions:
          type: integer
          description: |
            Vehicle’s carbon dioxide emission in g/km.
          example: 23
        consumption:
          description: Provides fuel and electric consumption information for the vehicle.
          allOf:
            - $ref: '#/components/schemas/Consumption'
        cylinderCapacity:
          type: integer
          minimum: 1
          maximum: 99999
          description: |
            Volume of the engines cylinders in cubic centimeters.
          example: 1998
        cylinderCount:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            The number of cylinders of the engine.
          example: 4
        description:
          type: string
          maxLength: 10000
          description: |
            Free text description of the vehicle.

            > Note that currently only the first 10000 characters are displayed. Generally 1 character is equal to 1 byte but characters from the extended alphabet like “ä” count as 2 bytes.
          example: |
            This car is **great**. \ It has the following features: \ * Low price \ * Great interior
        doorCount:
          type: integer
          minimum: 1
          maximum: 9
          description: |
            Number of doors the vehicle has
          example: 5
        drivetrain:
          type: string
          description: |
            Drive type of the vehicle.
          example: R
        efficiencyClass:
          type: integer
          description: |
            Vehicle’s energy efficiency class.
          example: 2
        electricRange:
          type: integer
          minimum: 1
          maximum: 10000
          example: 410
          description: The electric range of the vehicle in kilometers according to WLTP. (EAER)
        electricRangeCity:
          type: integer
          minimum: 1
          maximum: 10000
          example: 620
          description: The electric range of the vehicle in kilometers according to WLTP measured in cities. (EAER city)
        emptyWeight:
          type: integer
          minimum: 1
          maximum: 99999
          description: Vehicle’s weight without driver, passengers or liquids (like fuel) in kg.
          example: 1200
        equipment:
          type: array
          description: List of vehicle’s equipment
          example: [ 1, 2, 4, 15 ]
          uniqueItems: true
          items:
            type: integer
            description: |
              An equipment ID.
        euEmissionStandard:
          type: string
          description: |
            The EU emission standard indicates the amount of harmful substances the vehicle emits.
            The classification is in accordance with the European Standard Euronorm
          example: "1"
        firstRegistrationDate:
          type: string
          format: year-month
          description: |
            Month and year of first registration of the vehicle.
          example: 2015-01
        fuelCategory:
          type: string
          description: |
            Category of fuel/energy source for the vehicle.
            Allowed values can be retrieved via the references API (reference type FuelCategory)
          example: B
        gearCount:
          type: integer
          minimum: 1
          maximum: 9
          description: |
            Number of gears of the vehicle
          example: 6
        germanEmissionsSticker:
          type: integer
          description: |
            Emissions sticker type as assigned by German technical inspection authorities (Umweltplakette/Feinstaubplakette).
            Allowed values can be retrieved via the references API (reference type EmissionsSticker)
          example: 1
        hasCarRegistration:
          type: boolean
          description: |
            Indicates whether a vehicle is registered as a car in the registration documents
          example: false
        hasFullServiceHistory:
          type: boolean
          description: |
            Indicates whether vehicle has passed all periodic maintenance as recommended by the vehicle manufacturer.
          example: false
        hasParticleFilter:
          type: boolean
          description: |
            Indicates whether a diesel vehicle is equipped with a particle filter
          example: true
        hsn:
          type: string
          minLength: 4
          maxLength: 4
          description: |
            Herstellerschluesselnummer, or the unique identifier of vehicle manufacturer in Germany.
            In combination with TSN this key is used to uniquely identify a vehicle type.
            The make of a vehicle can be fully derived from this identifier.
          example: "0583"
        includedServices:
          type: array
          uniqueItems: true
          description: |
            Included services as part of the vehicle offer.
            Values <code>1</code> for German dealers (HU/AU) and <code>2</code> for Dutch dealers indicate that an inspection has been done recently and the vehicle is in a roadworthy state.
          items:
            type: integer
            description: |
              An included service ID.
          example: [ 1, 2 ]
        isMetallic:
          type: boolean
          description: |
            Whether the vehicle’s body color has a metallic effect.
          example: true
        isNonSmoking:
          type: boolean
          description: |
            Whether the vehicle has been used by non-smokers only.
          example: true
        isPluginHybrid:
          type: boolean
          description: |
            Whether the vehicle is a plugin hybrid.

            > If this property is set to <code>true</code>, then:
            
            > <code>primaryFuelType</code> OR <code>additionalFuelTypes</code> must contain <code>12</code> (Electric) AND <code>primaryFuelType</code> OR <code>additionalFuelTypes</code> must contain one fuel type != <code>12</code> (Electric)</li>
            
            > <code>fuelCategory</code> must be one of <code>3</code> (Electric/Diesel), <code>2</code> (Electric/Benzin) or <code>O</code> Others</li>
          example: true
        lastCamBeltServiceDate:
          type: string
          format: year-month
          description: |
            Date of last cam belt exchange.
            Cannot be in the future.
          example: 2016-01
        lastTechnicalServiceDate:
          type: string
          format: year-month
          description: Date of last periodic maintenance
          example: 2016-06
        licencePlate:
          type: string
          minLength: 1
          maxLength: 10
          description: Licence plate number of the vehicle
          example: M-2411-DC
        make:
          type: integer
          description: |
            Make identifier of the vehicle.
            Allowed values can be retrieved via the makes API

            > Mandatory for all listings
          example: 13
        model:
          type: integer
          description: |
            The model of the vehicle (for cars and bikes)
            Allowed values can be retrieved via the makes API
          example: 1641
        modelName:
          type: string
          maxLength: 50
          example: Sprinter 310 Carlsen
          description: |
            The model of the vehicle (for Light Commercial Vehicles, Trailers, Caravans/Mobile homes)
        modelVersion:
          type: string
          minLength: 1
          maxLength: 50
          description: |
            Additional information about the model
          example: Avant
        nextInspectionDate:
          type: string
          format: year-month
          description: |
            Date of next technical inspection as required by regulations.
          example: 2019-01
        offerReferenceId:
          type: string
          description: |
            A reference ID for the vehicle that can be used by buyers.
            Will be shown on the AutoScout24 plaform
          example: A12453
          minLength: 1
          maxLength: 50
        power:
          type: integer
          minimum: 1
          maximum: 9999
          description: |
            Engine power in kW. Power in (German) PS does not need to be specified, as it will automatically be derived from this value.
          example: 110
        previousOwnerCount:
          type: integer
          minimum: 0
          maximum: 99
          description: |
            Number of previous vehicle owners.
          example: 1
        primaryFuelType:
          type: integer
          description: |
            Fuel type with the lowest emission for the vehicle. This is derived from German emission/consumption regulations for vehicles (EnVKV).
            Allowed values can be retrieved via the references API (reference type FuelType).
          example: 1
        productionYear:
          type: string
          description: |
            The year when the vehicle was manufactured.
          example: "2014"
        seatCount:
          type: integer
          minimum: 1
          maximum: 99
          description: |
            Number of seats of the vehicle
          example: 5
        transmission:
          type: string
          description: |
            Specifies the transmission type of the vehicle (e.g. manual, automatic).
            Allowed values can be retrieved via the references API (reference type Transmission).
          example: "M"
        totalHeight:
          type: integer
          description: |
            Height of the vehicle in mm. Only available when vehicleType is <code>N</code>.
          example: 200
          minimum: 1
        totalLength:
          type: integer
          description: |
            Length of the vehicle in mm. Only available when vehicleType is <code>N</code>.
          example: 200
          minimum: 1
        totalWidth:
          type: integer
          description: |
            Width of the vehicle in mm. Only available when vehicleType is <code>N</code>
          example: 200
          minimum: 1
        tsn:
          type: string
          minLength: 3
          maxLength: 3
          description: |
            Typschluesselnummer: Identifier used by vehicle manufacturers in Germany to specify a vehicle type.
            From TSN the following parameters can be derived: Model, body, engine type, fuel type etc.
            Combined with HSN a make/model combination can be fully specified.
          example: "936"
        upholsteryColor:
          type: integer
          description: |
            Basic color of vehicle’s interior. Used to enable search by basic interior color.
            Allowed values can be retrieved via the references API (reference type InteriorColor)
          example: 1
        upholsteryType:
          type: string
          description: |
            The type of upholstery the vehicle has
            Allowed values can be retrieved via the references API (reference type Upholstery)
          example: "AL"
        vehicleType:
          description: |
            The type of vehicle being listed.

            > Mandatory for all listings
          allOf:
            - $ref: '#/components/schemas/VehicleTypeId'
        vin:
          type: string
          minLength: 17
          maxLength: 17
          description: |
            Vehicle Identification Number. A unique international code including a serial number used to identify individual motor vehicles, towed vehicles and motorcycles
          example: AB023475861123745
        wasCabOrRental:
          type: boolean
          description: |
            Whether the vehicle has been used as cab or rental car.
          example: false
        wheelbase:
          type: integer
          description: |
            The distance between the centers of the front and rear wheels, measured in millimeters.
          minimum: 1
          example: 2800
        wltp:
          description: Provides WLTP consumption information.
          allOf:
            - $ref: '#/components/schemas/WltpCommon'
            - $ref: '#/components/schemas/WltpUnits'
        youtubeVideoUrl:
          type: string
          format: url
          minLength: 1
          maxLength: 256
          description: |
            Youtube video for the vehicle.
          example: "https://www.youtube.com/watch?v=wnKJnWRa_Ks"
        emptyWeightUnit:
          type: string
          description: Unit used for emtyWeight field.
          example: kg
        alloyWheelSizeUnit:
          type: string
          description: Unit used for alloyWheel field.
          example: in
        co2EmissionsUnit:
          type: string
          description: Unit used for co2Emissions field.
          example: g/km
        combinedUnit:
          type: string
          description: Unit used for combined field.
          example: l/100km
        powerUnit:
          type: string
          description: Unit used for power field
          example: kW
        mileage:
          type: integer
          description: The distance that the vehicle has run
          example: 75000
        mileageUnit:
          type: string
          description: Unit used for mileage field
          example: km
        cylinderCapacityUnit:
          type: string
          description: Unit used for cylinderCapacity field
          example: m3
        payload:
          type: integer
          description: |
            Maximum payload the vehicle can carry.
          minimum: 0
          example: 2900
        payloadUnit:
          type: string
          description: Unit used for payload field
          example: kg
        grossVehicleWeight:
          type: integer
          description: |
            The maximum operating weight of a vehicle including its chassis, body, engine, engine fluids, fuel,
            accessories, driver, passengers and cargo.
          minimum: 1
          example: 3500
        grossVehicleWeightUnit:
          type: string
          description: Unit used for grossVehicleWeight field.
          example: kg
        loadHeight:
          type: integer
          description: Maximum height of the load.
          minimum: 1
          example: 1900
        loadHeightUnit:
          type: string
          description: Unit used for loadHeight field.
          example: mm
        loadVolumeUnit:
          type: string
          description: Unit used for loadVolume field.
          example: m3
        loadVolume:
          type: number
          description: Maximum volume of the load.
          example: 5.5
        loadWidthUnit:
          type: string
          description: Unit used for loadWidth field.
          example: mm
        loadWidth:
          type: integer
          description: Maximum width of the load.
          minimum: 1
          example: 2100
        loadLengthUnit:
          type: string
          description: Unit used for loadLength field.
          example: mm
        loadLength:
          type: integer
          description: Maximum length of the load.
          minimum: 1
          example: 3800
        wheelbaseUnit:
          type: string
          description: Unit used for wheelbase field.
          example: mm
        maximumTowingWeightUnit:
          type: string
          description: Unit used for maximumTowingWeight field.
          example: kg
        maximumTowingWeight:
          type: integer
          description: The maximum weight the vehicle can tow.
          minimum: 1
          example: 130
        totalHeightUnit:
          type: string
          description: Unit used for totalHeight field.
          example: mm
        totalLengthUnit:
          type: string
          description: Unit used for totalLength field.
          example: mm
        totalWidthUnit:
          type: string
          description: Unit used for totalWidth field.
          example: mm
        electricCombinedUnit:
          type: string
          description: Unit used for electricCombined field.
          example: kWh/100km
        costModel:
          description: Provides cost information for the vehicle.
          allOf:
            - $ref: '#/components/schemas/CostModel'
            - $ref: '#/components/schemas/CostModelUnits'

    ListingSharedAllSellersNoImages:
      allOf:
        - $ref: '#/components/schemas/BaseSharedAllSellersNoImages'
        - type: object
          properties:
            drivingMode:
              type: string
              description: |
                The drive type of the bike. Possible values are ChainDrive, BeltDrive, CrankDrive.
                > Forbidden for vehicleType <code>C</code> (car), <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home) and <code>L</code> (trailer)
              enum: [ "ChainDrive", "BeltDrive", "CrankDrive" ]
              example: "ChainDrive"
            europalletStorageSpaces:
              type: integer
              description: |
                The number of europallets that can be transported by the vehicle.
                > Forbidden for vehicleType <code>C</code> (car), <code>B</code> (bike) and <code>N</code> (caravan/mobile home)
              example: 5
            isEUReimport:
              type: boolean
              description: |
                Whether the vehicle is EU reimported.

                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            isReserved:
              type: boolean
              description: |
                Whether the vehicle is reserved.
                
                > This attribute is only available for Smyle listings at the moment. Its value won't be considered valid and won't be displayed in the AutoScout24 websites. This is up to change in the future.
              example: true
            schwackeCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
                > *Deprecated, use <code>natCode</code> instead*
              type: string
              maxLength: 22
              example: 20239429
            smyleVisibility:
              type: string
              description: |
                Visibility configuration for smyle listing. Set this field if this is a smyle listing and also you want to change the default visibility.
                Options:
                 - AS24: Show this listing only on the AS24 platform
                 - SMYLE: Show this listing only on the Smyle platform
                 - BOTH (default): Show this listing on both AS24 and SMYLE platforms.
                
                > This attribute is only available for Smyle listings.
              enum: [ "AS24", "SMYLE", "BOTH" ]
              example: "BOTH"
            twinner:
              description: Provides Twinner information for the vehicle.
              allOf:
                - $ref: '#/components/schemas/TwinnerPayload'
            natCode:
              description: |
                Classification of makes and models given by Eurotax/Schwacke
              type: string
              maxLength: 22
              example: '20239429'

    ListingSharedAllSellers:
      allOf:
        - $ref: '#/components/schemas/ListingSharedAllSellersNoImages'
        - type: object
          properties:
            images:
              type: array
              description: |
                The images that are associated with this listing.
              uniqueItems: true
              items:
                $ref: '#/components/schemas/Image'
              maxItems: 50
              example:
                - id: 269e6ae5-a49b-4ea5-85a2-9c2093c26287
                  previewUrl: "https://prod.pictures.autoscout24.net/listing-images/d0b91f24-68c2-4683-b575-db510e97fc2d_269e6ae5-a49b-4ea5-85a2-9c2093c26287.jpg"
                - id: 84c7df0f-6806-4d07-b667-cb7ed5109a61
                  previewUrl: "https://prod.pictures.autoscout24.net/listing-images/d0b91f24-68c2-4683-b575-db510e97fc2d_84c7df0f-6806-4d07-b667-cb7ed5109a61.jpg"

    ListingSummary:
      type: object
      required:
        - id
        - createdAt
        - lastUpdatedAt
      properties:
        id:
          type: string
          format: guid
          description: The unique identifier of the listing
          example: cf04da2d-9c57-4758-8735-5257e4eb1cae
        createdAt:
          type: string
          format: date-time
          description: |
            The time when the listing was created in ISO-8601 format.
          example: 2019-02-07T16:07:00.665267Z
        lastUpdatedAt:
          type: string
          format: date-time
          description: |
            The time when the listing was last updated in ISO-8601 format.
            This value can be used to decide whether the local copy of the listing in a given client is stale or not.
          example: 2019-03-07T16:07:00.665267Z
        offerReferenceId:
          type: string
          description: |
            A reference ID for the vehicle that can be used by buyers.
            Will be shown on the AutoScout24 plaform
          example: A12453
        crossReferenceId:
          type: string
          description: |
            Cross Reference Id is an identifier used by Data Providers.
          example: CA-A12453
        vinEnrichmentStatus:
          description: The status of the vin enrichment
          allOf:
            - $ref: '#/components/schemas/VinEnrichmentStatus'

    Listings:
      type: object
      required:
        - listings
      properties:
        listings:
          type: array
          description: the listings that were asked for
          items:
            $ref: '#/components/schemas/ListingSummary'

    Make:
      required:
        - id
        - name
        - models
        - vehicleTypes
      properties:
        id:
          description: an identifier of the make
          type: integer
          example: 13
        name:
          description: the name of the given make
          type: string
          example: BMW
        models:
          type: array
          description: the set of models that belong to this make
          items:
            $ref: '#/components/schemas/Model'
        vehicleTypes:
          type: array
          description: the vehicle types for which this make is available
          items:
            $ref: '#/components/schemas/VehicleTypeId'

    Makes:
      properties:
        makes:
          description: a set of makes
          type: array
          items:
            $ref: '#/components/schemas/Make'

    MarketingPayload:
      properties:
        exclusiveOffer:
          description: |
            Allows to use the product Exclusive Offer on this listing
            <strong>:construction: This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          allOf:
            - $ref: '#/components/schemas/ExclusiveOfferPayload'
        mia:
          description: Provides a manual override for the MIA product for this listing
          allOf:
            - $ref: '#/components/schemas/MiaPayload'
        listingBoost:
          description: |
            Allows to use the ListingBoost on this listing
            <strong>🚧 This functionality is currently under construction</strong>
          allOf:
            - $ref: '#/components/schemas/ListingBoostPayload'
        redPencil:
          type: boolean
          description: |
            Bookable feature indicating that the price of a vehicle was reduced, showing the old price and the new price.
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: false

    Marketing:
      properties:
        mia:
          description: Provides information about a possible manual override for the MIA product for this listing
          allOf:
            - $ref: '#/components/schemas/Mia'
        listingBoost:
          description: |
            Provides information about Listing Boost properties for this listing
            <strong>🚧 This functionality is currently under construction</strong>
          allOf:
            - $ref: '#/components/schemas/ListingBoost'
        exclusiveOffer:
          description: |
            Allows to use the product Exclusive Offer on this listing
            <strong>:construction: This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          allOf:
            - $ref: '#/components/schemas/ExclusiveOffer'
        redPencil:
          type: boolean
          description: |
            Bookable feature indicating that the price of a vehicle was reduced, showing the old price and the new price.
            <strong>🚧 This functionality is currently under construction and will not be shown to Autoscout24 users</strong>
          example: false

    Tier:
      type: string
      enum: [ "T20", "T30", "T40", "T50" ]
      description: |
        The tier increases the priority and visibility of a listing in the search results.
        Available tier levels are: <code>T20</code> (PlusInserat/Optimum…), <code>T30</code> (PremiumInserat/Premium), <code>T40</code> (PlatinumInserat/Platinum), <code>T50</code> (SalesTurbo)
      example: T20

    MiaPayload:
      properties:
        subtitle:
          type: string
          maxLength: 55
          description: |
            An additional vehicle description, will be shown for listings that have a tier applied.
            Note a tier can be applied manually or automatically, so this value should be sent even if the requestedTier field is not set.

            > URLs are forbidden in the content


            > Emails are forbidden in the content


            > Forbidden characters are<code>&lt;</code> or <code>&gt;</code>
            
            > Empty strings are not allowed

          example: First hand, from an authorized dealer. Discount.
        requestedTier:
          type: string
          enum:
            - "T20"
            - "T30"
          description: |
            Increases the priority and visibility of listings in the search results.
            Adding a tier will cause charges to the dealer.

            > Tiers can only be added for dealers that have a contract to this feature.


            > This can be checked in the customer endpoint in <code>canSetMiaRequestedTier</code>. If a customer can not request a mia tier, it will be silently ignored.


            > Available tier levels are: <code>T20</code> (PlusInserat/Optimum…), <code>T30</code> (PremiumInserat/Premium).


            > Its not possible to set <code>T40</code> or <code>T50</code> as a requestedTier.

          example: T20

    Mia:
      properties:
        subtitle:
          type: string
          maxLength: 55
          description: An additional vehicle description, will be shown for listings that have a tier applied.  Note a tier can be applied manually or automatically.
          example: First hand, from an authorized dealer. Discount.
        appliedTier:
          type: string
          enum:
            - "T20"
            - "T30"
            - "T40"
            - "T50"
          description: |
            The tier increases the priority and visibility of a listing in the search results, set from tier product.
            Available tier levels are: <code>T20</code> (PlusInserat/Optimum…), <code>T30</code> (PremiumInserat/Premium), <code>T40</code> (PlatinumInserat/Platinum), <code>T50</code> (SalesTurbo)
          example: T20

    ListingBoostPayload:
      properties:
        requested:
          type: boolean
          description: |
            Indicates whether the ListingBoost is requested.
          example: true

    ListingBoost:
      properties:
        requested:
          type: boolean
          description: Indicates whether the ListingBoost is requested.
          example: true
        applied:
          type: boolean
          description: Indicates whether the ListingBoost is applied.
          example: true

    Model:
      required:
        - id
        - name
        - vehicleType
      properties:
        id:
          description: an identifier of the model
          type: integer
          example: 1641
        name:
          description: the name of the given model
          type: string
          example: 320
        vehicleType:
          description: The type of vehicle.
          allOf:
            - $ref: '#/components/schemas/VehicleTypeId'

    Price:
      type: object
      description: Provides price information for the vehicle
      required:
        - price
        - currency
      properties:
        price:
          type: integer
          minimum: 1
          description: Gross price for the vehicle
          example: 16500
        currency:
          type: string
          enum: [ "EUR" ]
          description: Currency for given price.
          example: EUR

    PricesShared:
      type: object
      properties:
        public:
          description: |
            Gross price for the vehicle, including VAT and any other applicable taxes.
            This price will be shown to the AutoScout24 users.
          allOf:
            - $ref: '#/components/schemas/PublicPrice'
        manufacturersSuggestedRetail:
          description: |
            The retail price of the vehicle as suggested by its manufacturer
          allOf:
            - $ref: '#/components/schemas/RetailPrice'

    Prices:
      required:
        - public
      allOf:
        - $ref: '#/components/schemas/PricesShared'
        - type: object
          properties:
            dealer:
              description: The price of the vehicle when offered to dealers. Only shown in the dealer Marketplace.
              allOf:
                - $ref: '#/components/schemas/DealerPrice'

    PublicPrice:
      allOf:
        - $ref: '#/components/schemas/Price'
        - type: object
          properties:
            vatRate:
              type: number
              minimum: 0.0
              maximum: 100.0
              description: |
                The value added tax rate.

                > Only 1 decimal is accepted. If more decimals are sent they will be truncated.
              example: 17
            netPrice:
              type: integer
              minimum: 1
              description: |
                Net price for the vehicle
                
                > Must be less than <code>price</code>
              example: 15300

            isNegotiable:
              type: boolean
              description: Indicates whether a given price is negotiable
              example: false
            isTaxDeductible:
              type: boolean
              description: Indicates whether value added tax amount can be shown in invoice
              example: true
            germanEnvironmentalGrant:
              description: A one-time reimbursement a consumer can apply for. If priceAlreadyDiscounted is true, then the price / monthly rate is already calculated including this discount. If priceAlreadyDiscounted is false, then the price / monthly rate does not take the grant into account, but can be lowered by applying this discount.

              allOf:
                - $ref: '#/components/schemas/Discount'

    Publication:
      required:
        - status
        - channels
      properties:
        status:
          description: the status of the publication
          allOf:
            - $ref: '#/components/schemas/PublicationStatus'
        channels:
          description: |
            A channel to publish the listing to; publishing to the channel <code>AS24</code> implicitly publishes to <code>AS24Dealer</code> channel. Publishing to the channel <code>mobile_de</code> marks listings as eligible for export to mobile.de if the customer has opted-in to selective mobile.de export handling. If a customer has not opted-in (which is the default) but has an export to mobile.de configured, then all listings will be exported.
          type: array
          items:
            $ref: '#/components/schemas/Channel'

    PublicationPayload:
      required:
        - status
        - channels
      properties:
        status:
          description: the status of the publication
          allOf:
            - $ref: '#/components/schemas/PublicationStatus'
        channels:
          description: a channel to publish the listing to.
          type: array
          items:
            $ref: '#/components/schemas/ChannelReference'

    PublicationStatus:
      description: |
        Indicates whether a listing is published or unpublished
      type: string
      enum: [ "Active", "Inactive" ]
      example: "Inactive"

    RetailPrice:
      allOf:
        - $ref: '#/components/schemas/Price'

    Reference:
      required:
        - id
        - name
        - referenceType
      properties:
        id:
          description: A unique identifier of this reference. This value is unique within its reference type
          type: string
          example: "1"
        name:
          description: the name of the given reference in English
          type: string
          example: Compact
        referenceType:
          description: The type of reference
          allOf:
            - $ref: '#/components/schemas/ReferenceType'
        vehicleType:
          type: array
          description: The vehicle types to which this reference applies.
          items:
            $ref: '#/components/schemas/VehicleTypeId'
        country:
          description: The countries to which this reference applies.
          type: array
          items:
            type: string
            description: |
              Each of the countries.
              Allowed values can be retrieved via the references API (reference type Country).
          example: [ "DE", "AT" ]

    References:
      properties:
        references:
          description: a set of references
          type: array
          items:
            $ref: '#/components/schemas/Reference'

    ReferenceType:
      description: the type of reference
      type: string
      enum:
        - "AvailabilityType"
        - "BatteryOwnershipType"
        - "BodyColor"
        - "BodyType"
        - "Co2Class"
        - "Country"
        - "DebitInterestType"
        - "Drivetrain"
        - "EfficiencyClass"
        - "Equipment"
        - "EuEmissionStandard"
        - "FuelCategory"
        - "FuelType"
        - "GermanEmissionsSticker"
        - "IncludedService"
        - "OfferType"
        - "PriceLabel"
        - "Transmission"
        - "UpholsteryColor"
        - "UpholsteryType"
        - "VehicleType"
      example: BodyType

    Seal:
      required:
        - id
        - name
        - country
      properties:
        id:
          description: an identifier of the seal
          type: integer
          example: 10
        name:
          description: the name of given seal
          type: string
          example: Best Car Selection
        country:
          description: country for given seal (as ISO code)
          type: string
          example: NL-nl
        thumbnail:
          description: URL to the thumbnail image of the seal
          type: string
          example: "https://prod.pictures.autoscout24.net/seals/10.jpg"
        image:
          description: URL to the image of the seal
          type: string
          example: "https://prod.pictures.autoscout24.net/seals/10.jpg"
        info:
          description: URL to the information page of the seal
          type: string
          example: "https://www.autoscout24.nl/best-car-selection"
        manuallyEditable:
          description: Whether the seal can be manually edited by the dealer
          type: boolean
          example: false
        classId:
          description: The class of the seal
          type: integer
          example: 1
        defaultSet:
            description: Whether the seal is set by default
            type: boolean
            example: false

    Seals:
      properties:
        seals:
          description: a set of seals
          type: array
          items:
            $ref: '#/components/schemas/Seal'

    ThreeSixtyImagesCollection:
      allOf:
        - $ref: '#/components/schemas/ThreeSixtyImagesCollectionPayload'
        - $ref: '#/components/schemas/ImageReference'

    ThreeSixtyImagesCollectionImage:
      allOf:
        - $ref: '#/components/schemas/ImageReference'
        - $ref: '#/components/schemas/ImageMd5'

    ThreeSixtyImagesCollectionImagePayload:
      allOf:
        - $ref: '#/components/schemas/ImageReference'

    ThreeSixtyImagesCollectionPayload:
      type: object
      required:
        - images
      properties:
        images:
          description: |
            The list of images that compose the 360 image, in order of visualization.
          type: array
          minItems: 4
          maxItems: 75
          items:
            $ref: '#/components/schemas/ThreeSixtyImagesCollectionImagePayload'

    ThreeSixtyImagesCollections:
      required:
        - images
      properties:
        images:
          description: list of all images of type <code>ThreeSixtyImagesCollection</code> for the listing
          type: array
          items:
            $ref: '#/components/schemas/ThreeSixtyImagesCollection'

    ThreeSixtyVr:
      allOf:
        - $ref: '#/components/schemas/ImageReference'
        - $ref: '#/components/schemas/ImageMd5'
        - type: object
          properties:
            format:
              type: string
              enum: [ Equirectangular ]
              description: the format of the VR image
              example: Equirectangular
            previewUrl:
              description: the URL of the highest resolution version of the image
              type: string
              example: "https://prod.pictures.autoscout24.net/listing-images/d0b91f24-68c2-4683-b575-db510e97fc2d_e5079988-9e05-43f0-8cba-6f37e6f1de28.jpg"


    ThreeSixtyVrs:
      required:
        - images
      properties:
        images:
          description: list of all images of type ThreeSixtyVr for the listing
          type: array
          items:
            $ref: '#/components/schemas/ThreeSixtyVr'

    TwinnerPayload:
      properties:
        key:
          description: The url as retrieved from Twinner
          type: string
          example: https://data.twinner.com/displaydata/20211210/102/121021_d3ebf51e-1a07-4d97-b0f2-d830bb8601b3/

    VehicleTypeId:
      type: string
      enum: [ "C", "B", "N", "X", "L" ]
      description: |
        A type of vehicle.
        We currently support: <code>C</code> (cars), <code>B</code> (bikes), <code>X</code> (light commercial vehicle), <code>N</code> (caravan/mobile home), <code>L</code> (trailer)

        > Allowed values can be retrieved via the references API (reference type VehicleType)

      example: C

    VinEnrichmentStatus:
      description: |
        Indicates the status of enrichment
      type: string
      enum: [ "Processing", "Success", "Fail" ]
      example: "Success"

    WltpCommon:
      properties:
        co2EmissionsCombined:
          type: number
          minimum: 1
          maximum: 10000
          example: 85.4
          description: |
            The combined co2 emissions according to WLTP in g/km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), <code>primaryFuelType</code> is either <code>12</code> (electric) and no <code>additionalFuelTypes</code> is set or <code>primaryFuelType</code> is not <code>12</code> (electric) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        co2EmissionsCombinedWeighted:
          type: number
          minimum: 1
          maximum: 10000
          example: 84.4
          description: |
            The weighted combined co2 emissions for plug-in-hybrids according to WLTP in g/km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is <code>12</code> (electric) and <code>additionalFuelTypes</code> is not empty and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionCombined:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 83.4
          description: |
            The combined consumption according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is not <code>12</code> (electric) and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionElectricCombined:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 82.4
          description: |
            The combined electric consumption according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is <code>12</code> (electric) and no <code>additionalFuelTypes</code> and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionCombinedWeighted:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 81.4
          description: |
            The combined consumption according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is <code>12</code> (electric) and <code>additionalFuelTypes</code> is not empty and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionElectricCombinedWeighted:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            The combined electric weighted consumption according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is <code>12</code> (electric) and <code>additionalFuelTypes</code> is not empty and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        co2Class:
          type: integer
          example: 10 (meaning A)
          description: |
            Vehicles co2 class.

            > Allowed values can be retrieved via the references API (reference type Co2Class)

            > Mandatory for German dealers when vehicleType is <code>C</code> and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)
            
            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        co2ClassDischarged:
          type: integer
          example: 10 (meaning A)
          description: |
            Plug-In-Hybrid co2 class for discharged battery.

            > Allowed values can be retrieved via the references API (reference type Co2Class)

            > Mandatory for German dealers and plug in hybrids when vehicleType is <code>C</code> and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)
            
            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionCombinedDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            The combined consumption for plug-in hybrids with empty battery according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Mandatory for German dealers when the vehicle type is <code>C</code> (Car), primaryFuelType is <code>12</code> (electric) and <code>additionalFuelTypes</code> is not empty and the car is considered new (<code>mileage</code> <= 1000 and <code>firstRegistrationDate</code> <= 8 months).

            > Forbidden for vehicleType <code>L</code> (trailer)

            > Forbidden if NEDC consumption values are set (<code>consumption</code>, <code>co2Emissions</code> or <code>efficiencyClass</code>)
        consumptionCity:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 7.2
          description: |
            The fuel consumption according to WLTP in l/100km, one decimal place.
            
            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for ICE and Mild/full Hybrids.
        consumptionCityDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 9.3
          description: |
            The fuel consumption in the city with discharged battery according to WLTP in l/100km, one decimal place.
            
            > Only one decimal place is accepted. If more decimals are sent they will be truncated.

            > Optional for PHEV.
        consumptionSuburban:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 5.1
          description: |
            The fuel consumption in suburban areas according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for ICE and Mild/full Hybrids.
        consumptionRural:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 4.2
          description: |
            The fuel consumption in rural areas according to WLTP in l/100km, one decimal place.
            
            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for ICE and Mild/full Hybrids.
        consumptionHighway:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            The fuel consumption on highways according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for ICE and Mild/full Hybrids.
        consumptionElectricCity:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 14.8
          description: |
            The electric consumption in the city according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for EV and PHEV.
        consumptionElectricSuburban:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 14.8
          description: |
            The electric consumption in suburban areas according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for EV and PHEV.
        consumptionElectricRural:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 14.8
          description: |
            The electric consumption in rural areas according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for EV and PHEV.
        consumptionElectricHighway:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 19.2
          description: |
            The electric consumption on highways according to WLTP in kWh/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for EV and PHEV.
        consumptionSuburbanDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 8.3
          description: |
            The fuel consumption in suburban areas with discharged battery according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for PHEV.
        consumptionRuralDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 8.4
          description: |
            The fuel consumption in rural areas with discharged battery according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for PHEV.
        consumptionHighwayDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 8.5
          description: |
            The fuel consumption on highways with discharged battery according to WLTP in l/100km, one decimal place.

            > Only one decimal place is accepted. If more decimals are sent they will be truncated.
            
            > Optional for PHEV.
        co2EmissionsDischarged:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 116.2
          description: |
            The CO2 emissions with a discharged battery according to WLTP in g/km, one decimal place.
            
            > Optional for PHEV.

    WltpUnits:
      properties:
        co2EmissionsCombinedUnit:
          type: string
          description: Unit used for co2EmissionsCombined field
          example: g/km
        co2EmissionsCombinedWeightedUnit:
          type: string
          description: Unit used for co2EmissionsCombinedWeighted field
          example: g/km
        consumptionCombinedUnit:
          type: string
          description: Unit used for consumptionCombined field
          example: l/100km
        consumptionElectricCombinedUnit:
          type: string
          description: Unit used for consumptionElectricCombined field
          example: kWh/100km
        consumptionCombinedWeightedUnit:
          type: string
          description: Unit used for consumptionCombinedWeighted field
          example: l/100km
        consumptionElectricCombinedWeightedUnit:
          type: string
          description: Unit used for consumptionElectricCombinedWeighted field
          example: kWh/100km
        consumptionCombinedDischargedUnit:
          type: string
          description: Unit used for consumptionCombinedDischarged field
          example: l/100km
        consumptionCityUnit:
          type: string
          description: Unit used for consumptionCity field
          example: l/100km
        consumptionCityDischargedUnit:
          type: string
          description: Unit used for consumptionCityDischarged field
          example: l/100km
        consumptionSuburbanUnit:
          type: string
          description: Unit used for consumptionSuburban field
          example: l/100km
        consumptionRuralUnit:
          type: string
          description: Unit used for consumptionRural field
          example: l/100km
        consumptionHighwayUnit:
          type: string
          description: Unit used for consumptionHighway field
          example: l/100km
        consumptionElectricCityUnit:
          type: string
          description: Unit used for consumptionElectricCity field
          example: kWh/100km
        consumptionElectricSuburbanUnit:
          type: string
          description: Unit used for consumptionElectricSuburban field
          example: kWh/100km
        consumptionElectricRuralUnit:
          type: string
          description: Unit used for consumptionElectricRural field
          example: kWh/100km
        consumptionElectricHighwayUnit:
          type: string
          description: Unit used for consumptionElectricHighway field
          example: kWh/100km
        consumptionSuburbanDischargedUnit:
          type: string
          description: Unit used for consumptionElectricHighway field
          example: l/100km
        consumptionRuralDischargedUnit:
          type: string
          description: Unit used for consumptionRuralDischarged field
          example: l/100km
        consumptionHighwayDischargedUnit:
          type: string
          description: Unit used for consumptionHighwayDischarged field
          example: l/100km
        co2EmissionsDischargedUnit:
          type: string
          description: Unit used for co2EmissionsDischarged field
          example: g/km

    Co2Price:
      properties:
        basePrice:
          type: number
          minimum: 0.1
          maximum: 100000
          example: 80.4
          description: |
            The base CO2 price.
        accumulated:
          type: number
          minimum: 0.1
          maximum: 100000
          example: 80.4
          description: |
            The accumulated CO2 price. 

    Co2Costs:
      description: |
        The CO2 costs for the vehicle.
      properties:
        low:
          description: |
            The low CO2 costs.
          allOf:
            - $ref: '#/components/schemas/Co2Price'
        average:
          description: |
            The average CO2 costs.
          allOf:
            - $ref: '#/components/schemas/Co2Price'
        high:
          description: |
            The high CO2 costs.
          allOf:
            - $ref: '#/components/schemas/Co2Price'
    CostModelCommon:
      properties:
        co2Costs:
          type: object
          allOf:
            - $ref: '#/components/schemas/Co2Costs'
          description: |
            The CO2 costs.
          example:
            low:
              basePrice: 80.4
              accumulated: 80.4
            average:
              basePrice: 80.4
              accumulated: 80.4
            high:
              basePrice: 80.4
              accumulated: 80.4
        consumptionCosts:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            Energy costs for an annual mileage of 15,000 km in EUR/year.
        consumptionCostsYear:
          type: string
          example: "2024"
          description: |
            Year of consumptionCosts.
        energyPrice:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            The price of electric energy in ct/kWh.
        fuelPrice:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 80.4
          description: |
            The fuel price in EUR/l (Benzin, Diesel, LPG) or EUR/kg (CNG, H2).
        timeFrame:
          type: object
          properties:
            start:
              type: string
              description: |
                The start year of the tax estimation time frame.
              example: 2024
            end:
              type: string
              description: |
                The end year of the tax estimation time frame.
              example: 2024
          description: |
            The time frame for the tax estimation.
          example: |
            start: 2024
            end: 2024
        vehicleTax:
          type: number
          minimum: 0.1
          maximum: 10000
          example: 223.4
          description: |
            The vehicle tax.

    CostModelUnits:
      properties:
        consumptionCostsUnit:
          type: string
          description: Unit used for consumptionCosts field
          example: EUR/year
        energyPriceUnit:
          type: string
          description: Unit used for energyPrice field
          example: EUR/kg
        fuelPriceUnit:
          type: string
          description: Unit used for fuelPrice field
          example: EUR/l
        vehicleTaxUnit:
          type: string
          description: Unit used for vehicleTax field
          example: EUR/year

    CostModelPayload:
      allOf:
        - $ref: '#/components/schemas/CostModelCommon'

    CostModel:
      allOf:
        - $ref: '#/components/schemas/CostModelCommon'
        - $ref: '#/components/schemas/CostModelUnits'

    ListingsStatisticsWrapper:
      required:
        - customerId
        - listings
        - snapshotDate
      properties:
        customerId:
          type: string
          description: The unique identifier of the customer
          example: 12345678
        listings:
          type: array
          description: the listings that were asked for
          items:
            $ref: '#/components/schemas/SingleListingStatistic'
        snapshotDate:
          type: string
          format: date-time
          description: |
            The time when the statistics were generated in ISO-8601 format.
          example: 2019-03-07T16:07:00.665267Z

    ListingsStatisticsWrapperPaged:
      allOf:
        - $ref: '#/components/schemas/ListingsStatisticsWrapper'
        - $ref: '#/components/schemas/CursorPagination'

    SingleListingStatistic:
      required:
        - id
        - priceLabelIndex
        - emailLeads
        - detailPageClicks
        - listPageViews
        - favorites
        - prints
        - calls
        - daysInStock
        - whatsAppClicks
      properties:
        id:
          type: string
          description: The unique identifier of the listing.
          example: cf04da2d-9c57-4758-8735-5257e4eb1cae
        priceLabelIndex:
          type: integer
          description: The price label index of the listing.
          example: 1
        emailLeads:
          type: integer
          description: The number of email leads of the listing.
          example: 1
        detailPageClicks:
          type: integer
          description: The number of clicks of the listing.
          example: 1
        listPageViews:
          type: integer
          description: The number of list page views of the listing.
          example: 1
        favorites:
          type: integer
          description: The number of favorites of the listing.
          example: 1
        prints:
          type: integer
          description: The number of prints of the listing.
          example: 1
        calls:
          type: integer
          description: The number of calls for the listing.
          example: 1
        probabilityToSellFast:
          type: string
          enum:
            - Low
            - Medium
            - High
          description: |
            The probability that this listing will be sold in the first 60 days.
            Optional, might not be set. String value is one of <code>High</code>, <code>Medium</code>, <code>Low</code>
            and is calculated based on the performance of similar listings.
          example: High
        daysInStock:
          type: integer
          description: The number of days since the listing creation.
          example: 1
        whatsAppClicks:
          type: integer
          description: The number of WhatsApp clicks of the listing.
          example: 1
        priceLabelRanges:
          type: array
          description: The price label ranges of the listing.
          items:
            type: object
            required:
              - category
              - minimum
              - maximum
            properties:
              category:
                type: integer
                description: The price label category index, can be mapped using the references endpoint for the reference type PriceLabel.
                example: 1
              minimum:
                type: integer
                description: The inclusive minimum price for this listing to be in this price range.
                example: 10500
              maximum:
                type: integer
                description: The inclusive maximum price for this listing to be in this price range.
                example: 13500

    Errors:
      properties:
        errors:
          description: A list of errors that occured when trying to execute the request
          type: array
          items:
            $ref: '#/components/schemas/Error'

    Error:
      properties:
        code:
          type: string
          description: The type of error that occurred when trying to execute the request
          enum:
            - "address-is-required"
            - "attribute-contains-prohibited-content"
            - "attribute-is-zero-or-negative"
            - "batch-id-is-invalid"
            - "cannot-partially-update-listing"
            - "city-is-required"
            - "content-type-not-provided"
            - "country-code-is-not-supported"
            - "customer-cannot-sell-online"
            - "customer-not-found-error"
            - "duplicated-image"
            - "empty-body"
            - "empty-three-sixty-images-collection"
            - "first-registration-date-too-modern"
            - "first-registration-date-too-old"
            - "forbidden-attribute-present"
            - "forbidden-leasing-offer-attribute-present"
            - "image-does-not-exist"
            - "image-not-readable"
            - "image-with-invalid-content-type"
            - "images-not-found"
            - "invalid-additional-supported-fuel-types"
            - "invalid-area-code-in-phone-number"
            - "invalid-availability"
            - "invalid-belgian-carpass-mileage-url"
            - "invalid-body-color"
            - "invalid-body-type"
            - "invalid-body-type-when-has-no-engine"
            - "invalid-co-2-class"
            - "invalid-co-2-class-discharged"
            - "invalid-condition-data"
            - "invalid-content-type"
            - "invalid-country-version"
            - "invalid-debit-interest-type"
            - "invalid-dial-country-code-in-phone-number"
            - "invalid-drivetrain"
            - "invalid-efficiency-class"
            - "invalid-equipment"
            - "invalid-eu-emission-standard"
            - "invalid-field-length"
            - "invalid-financing-type"
            - "invalid-fuel-category"
            - "invalid-fuel-type-or-category-for-plugin-hybrid"
            - "invalid-german-emissions-sticker"
            - "invalid-has-warranty-type"
            - "invalid-included-services"
            - "invalid-json"
            - "invalid-leasing-offer-country"
            - "invalid-listing-payload"
            - "invalid-make"
            - "invalid-make-with-replacement"
            - "invalid-mileage"
            - "invalid-model"
            - "invalid-model-with-replacement"
            - "invalid-model-version"
            - "invalid-next-inspection-date"
            - "invalid-offer-type"
            - "invalid-phone-number"
            - "invalid-previous-owners-count"
            - "invalid-price-currency"
            - "invalid-price-value"
            - "invalid-primary-fuel-type"
            - "invalid-publication-status"
            - "invalid-reference"
            - "invalid-references"
            - "invalid-requested-seals"
            - "invalid-requested-tier"
            - "invalid-transmission"
            - "invalid-twinner-key"
            - "invalid-upholstery-color"
            - "invalid-upholstery-type"
            - "invalid-uuid"
            - "invalid-vehicle-type"
            - "invalid-year-range"
            - "invalid-you-tube-video-url"
            - "json-not-found"
            - "last-cam-belt-service-cannot-be-in-the-future"
            - "listing-creation-limit-exceeded"
            - "listing-does-not-exist"
            - "listing-does-not-exist-or-has-overwrite-protection"
            - "listing-on-hold-cannot-be-updated"
            - "listings-do-not-exist"
            - "mandatory-attribute-missing"
            - "maximum-image-resolution-exceeded"
            - "maximum-image-size-exceeded"
            - "maximum-value-exceeded"
            - "maximum-value-exceeded-emission-consumption"
            - "minimum-image-resolution-not-met"
            - "minimum-value-exceeded"
            - "minimum-value-exceeded-emission-consumption"
            - "phone-number-requires-address"
            - "publication-not-contains-as24-or-as24-dealer-channel"
            - "invalid-publication-channel"
            - "quoka-listing-requires-address"
            - "service-under-maintenance"
            - "standard-image-does-not-support-vr-format"
            - "three-sixty-images-collection-too-few-images"
            - "three-sixty-images-collection-too-many-images"
            - "three-sixty-vr-unsupported-format"
            - "too-many-highlights"
            - "too-many-images"
            - "unsupported-image-type"
            - "upload-360-image-failed"
            - "upload-image-failed"
            - "wltp-and-nedc-set-error"
            - "wltp-attribute-forbidden-for-engine-type"
            - "wltp-attribute-required-for-engine-type"
            - "wltp-co-2-emissions-combined-for-evs-invalid"
            - "wltp-test-mode-only-error"
            - "zip-code-is-required"
            - "invalid-internal-status"
            - "vehicle-does-not-exist"
          example: "empty-body"
        message:
          type: string
          description: A detailed explanation of the error
          example: |
            The property 'prices' could not be found
